@@ -1,13 +1,12 @@
 package Dist::Zilla;
-BEGIN {
-  $Dist::Zilla::VERSION = '4.101800';
+{
+  $Dist::Zilla::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: distribution builder; installer not included!
 use Moose 0.92; # role composition fixes
 with 'Dist::Zilla::Role::ConfigDumper';
 
 use Moose::Autobox 0.09; # ->flatten
-use MooseX::LazyRequire;
 use MooseX::Types::Moose qw(ArrayRef Bool HashRef Object Str);
 use MooseX::Types::Perl qw(DistName LaxVersionStr);
 use MooseX::Types::Path::Class qw(Dir File);
@@ -15,7 +14,6 @@ use Moose::Util::TypeConstraints;
 
 use Dist::Zilla::Types qw(License);
 
-use Hash::Merge::Simple ();
 use Log::Dispatchouli 1.100712; # proxy_loggers, quiet_fatal
 use Path::Class;
 use List::Util qw(first);
@@ -41,7 +39,8 @@ has chrome => (
 has name => (
   is   => 'ro',
   isa  => DistName,
-  lazy_required => 1,
+  lazy => 1,
+  builder => '_build_name',
 );
 
 
@@ -57,10 +56,26 @@ has version => (
   isa  => LaxVersionStr,
   lazy => 1,
   init_arg  => undef,
-  required  => 1,
   builder   => '_build_version',
 );
 
+sub _build_name {
+  my ($self) = @_;
+
+  my $name;
+  for my $plugin ($self->plugins_with(-NameProvider)->flatten) {
+    next unless defined(my $this_name = $plugin->provide_name);
+
+    $self->log_fatal('attempted to set name twice') if defined $name;
+
+    $name = $this_name;
+  }
+
+  $self->log_fatal('no name was ever set') unless defined $name;
+
+  $name;
+}
+
 sub _build_version {
   my ($self) = @_;
 
@@ -84,7 +99,6 @@ has abstract => (
   is   => 'rw',
   isa  => 'Str',
   lazy => 1,
-  required => 1,
   default  => sub {
     my ($self) = @_;
 
@@ -92,11 +106,12 @@ has abstract => (
       die "no abstract given and no main_module found; make sure your main module is in ./lib\n";
     }
 
-    my $filename = $self->main_module->name;
-    $self->log("extracting distribution abstract from $filename");
-    my $abstract = Dist::Zilla::Util->abstract_from_file($filename);
+    my $file = $self->main_module;
+    $self->log("extracting distribution abstract from " . $file->name);
+    my $abstract = Dist::Zilla::Util->abstract_from_file($file);
 
     if (!defined($abstract)) {
+        my $filename = $file->name;
         die "Unable to extract an abstract from $filename. Please add the following comment to the file with your abstract:
     # ABSTRACT: turns baubles into trinkets
 ";
@@ -119,13 +134,13 @@ has main_module => (
   isa  => 'Dist::Zilla::Role::File',
   lazy => 1,
   init_arg => undef,
-  required => 1,
   default  => sub {
 
     my ($self) = @_;
 
     my $file;
     my $guessing = q{};
+    my $guess;
 
     if ( $self->_has_main_module_override ) {
        $file = first { $_->name eq $self->_main_module_override }
@@ -133,7 +148,7 @@ has main_module => (
     } else {
        $guessing = 'guessing '; # We're having to guess
 
-       (my $guess = $self->name) =~ s{-}{/}g;
+       ($guess = $self->name) =~ s{-}{/}g;
        $guess = "lib/$guess.pm";
 
        $file = (first { $_->name eq $guess } $self->files->flatten)
@@ -143,8 +158,23 @@ has main_module => (
              ->head;
     }
 
-    $self->log_fatal("Unable to find main_module in dist") unless $file;
+    if (not $file) {
+        my @errorlines;
 
+        push @errorlines, "Unable to find main_module in the distribution";
+        if ( $self->_has_main_module_override ) {
+            push @errorlines, "'main_module' was specified in dist.ini but the file '" . $self->_main_module_override . "' is not to be found in our dist. ( Did you add it? )";
+        } else {
+            push @errorlines,"We tried to guess '$guess' but no file like that existed";
+        }
+        if ( not $self->files->flatten ) {
+            push @errorlines, "Upon further inspection we didn't find any files in your dist, did you add any?";
+        } elsif ( not $self->files->grep(sub{ $_->name =~ m{\.pm\z} })->head ){
+            push @errorlines, "We didn't find any .pm files in your dist, this is probably a problem.";
+        }
+        push @errorlines,"Cannot continue without a main_module";
+        $self->log_fatal( join qq{\n}, @errorlines );
+    }
     $self->log("${guessing}dist's main_module is " . $file->name);
 
     return $file;
@@ -172,6 +202,24 @@ sub _build_license {
   my $copyright_holder = $self->_copyright_holder;
   my $copyright_year   = $self->_copyright_year;
 
+  my $provided_license;
+
+  for my $plugin ($self->plugins_with(-LicenseProvider)->flatten) {
+    my $this_license = $plugin->provide_license({
+      copyright_holder => $copyright_holder,
+      copyright_year   => $copyright_year,
+    });
+
+    next unless defined $this_license;
+
+    $self->log_fatal('attempted to set license twice')
+      if defined $provided_license;
+
+    $provided_license = $this_license;
+  }
+
+  return $provided_license if defined $provided_license;
+
   if ($license_class) {
     $license_class = String::RewritePrefix->rewrite(
       {
@@ -189,7 +237,8 @@ sub _build_license {
     if (@guess != 1) {
       $self->log_fatal(
         "no license data in config, no %Rights stash,",
-        "couldn't make a good guess at license from Pod; giving up"
+        "couldn't make a good guess at license from Pod; giving up. ",
+        "Perhaphs you need set global config file (dzil setup)?"
       );
     }
 
@@ -198,7 +247,7 @@ sub _build_license {
     $self->log("based on POD in $filename, guessing license is $guess[0]");
   }
 
-  Class::MOP::load_class($license_class);
+  Class::Load::load_class($license_class);
 
   my $license = $license_class->new({
     holder => $self->_copyright_holder,
@@ -263,7 +312,6 @@ has authors => (
   is   => 'ro',
   isa  => ArrayRef[Str],
   lazy => 1,
-  required => 1,
   default  => sub {
     my ($self) = @_;
 
@@ -341,13 +389,13 @@ sub _build_distmeta {
   my $meta = {
     'meta-spec' => {
       version => 2,
-      url     => 'http://github.com/dagolden/cpan-meta/',
+      url     => 'http://search.cpan.org/perldoc?CPAN::Meta::Spec',
     },
     name     => $self->name,
     version  => $self->version,
     abstract => $self->abstract,
     author   => $self->authors,
-    license  => $self->license->meta2_name,
+    license  => [ $self->license->meta2_name ],
 
     # XXX: what about unstable?
     release_status => ($self->is_trial or $self->version =~ /_/)
@@ -360,8 +408,15 @@ sub _build_distmeta {
                     . (defined $self->VERSION ? $self->VERSION : '(undef)')
   };
 
-  $meta = Hash::Merge::Simple::merge($meta, $_->metadata)
-    for $self->plugins_with(-MetaProvider)->flatten;
+  require Hash::Merge::Simple;
+  my $dynamic;
+  for ($self->plugins_with(-MetaProvider)->flatten) {
+    my $plugin_meta = $_->metadata;
+    $meta = Hash::Merge::Simple::merge($meta, $plugin_meta);
+    $dynamic = 1 if $plugin_meta->{dynamic_config};
+  }
+
+  $meta->{dynamic_config} = 1 if $dynamic;
 
   return $meta;
 }
@@ -444,14 +499,12 @@ sub _write_out_file {
 
   Carp::croak("attempted to write $to multiple times") if -e $to;
 
-  open my $out_fh, '>', "$to" or die "couldn't open $to to write: $!";
-
   # This is needed, or \n is translated to \r\n on win32.
   # Maybe :raw:utf8 is needed, but not sure.
   #     -- Kentnl - 2010-06-10
-  binmode( $out_fh , ":raw" );
+  open my $out_fh, '>:raw', "$to" or die "couldn't open $to to write: $!";
 
-  print { $out_fh } $file->content;
+  print { $out_fh } $file->encoded_content;
   close $out_fh or die "error closing $to: $!";
   chmod $file->mode, "$to" or die "couldn't chmod $to: $!";
 }
@@ -499,16 +552,19 @@ sub stash_named {
 __PACKAGE__->meta->make_immutable;
 1;
 
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla - distribution builder; installer not included!
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -681,19 +737,61 @@ There is a mailing list to discuss Dist::Zilla.  You can L<join the
 list|http://www.listbox.com/subscribe/?list_id=139292> or L<browse the
 archives|http://listbox.com/member/archive/139292>.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item *
+
+In the Dist::Zilla distribution:
+
+=over 4
+
+=item *
+
+Plugin bundles:
+L<@Basic|Dist::Zilla::PluginBundle::Basic>,
+L<@Filter|Dist::Zilla::PluginBundle::Filter>.
+
+=item *
+
+Major plugins:
+L<GatherDir|Dist::Zilla::Plugin::GatherDir>,
+L<Prereqs|Dist::Zilla::Plugin::Prereqs>,
+L<AutoPrereqs|Dist::Zilla::Plugin::AutoPrereqs>,
+L<MetaYAML|Dist::Zilla::Plugin::MetaYAML>,
+L<MetaJSON|Dist::Zilla::Plugin::MetaJSON>,
+...
+
+=back
+
+=item *
+
+On the CPAN:
+
+=over 4
+
+=item *
+
+Search for plugins: L<https://metacpan.org/search?q=Dist::Zilla::Plugin::>
+
+=item *
+
+Search for plugin bundles: L<https://metacpan.org/search?q=Dist::Zilla::PluginBundle::>
+
+=back
+
+=back
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
