@@ -1,17 +1,16 @@
 use strict;
 use warnings;
 package Dist::Zilla::App;
-BEGIN {
-  $Dist::Zilla::App::VERSION = '4.101800';
+{
+  $Dist::Zilla::App::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: Dist::Zilla's App::Cmd
-use App::Cmd::Setup 0.307 -app; # need ->app in Result of Tester, GLD vers
+use App::Cmd::Setup 0.309 -app; # better compilation error detection
 
 use Carp ();
 use Dist::Zilla::MVP::Reader::Finder;
-use File::HomeDir ();
+use Dist::Zilla::Util;
 use Moose::Autobox;
-use Path::Class;
 use Try::Tiny;
 
 sub global_opt_spec {
@@ -23,23 +22,17 @@ sub global_opt_spec {
   );
 }
 
-sub _config_root {
-  return dir($ENV{DZIL_GLOBAL_CONFIG_ROOT}) if $ENV{DZIL_GLOBAL_CONFIG_ROOT};
-
-  my $homedir = File::HomeDir->my_home
-    or Carp::croak("couldn't determine home directory");
-
-  return dir($homedir)->subdir('.dzil');
-}
-
 sub _build_global_stashes {
   my ($self) = @_;
 
   return $self->{__global_stashes__} if $self->{__global_stashes__};
 
+  # tests shouldn't depend on the user's configuration
+  return {} if $ENV{DZIL_TESTING};
+
   my $stash_registry = $self->{__global_stashes__} = {};
 
-  my $config_dir  = $self->_config_root;
+  my $config_dir  = Dist::Zilla::Util->_global_config_root;
 
   my $config_base = $config_dir->file('config');
 
@@ -54,12 +47,12 @@ sub _build_global_stashes {
   try {
     my $reader = Dist::Zilla::MVP::Reader::Finder->new({
       if_none => sub {
-        warn <<'END_WARN';
-WARNING: No global configuration file was found in ~/.dzil -- this limits the
-ability of Dist::Zilla to perform some tasks.  You can run "dzil setup" to
-create a simple first-pass configuration file, or you can touch the file
-~/.dzil/config.ini to suppress this message in the future.
-END_WARN
+#         warn <<'END_WARN';
+# WARNING: No global configuration file was found in ~/.dzil -- this limits the
+# ability of Dist::Zilla to perform some tasks.  You can run "dzil setup" to
+# create a simple first-pass configuration file, or you can touch the file
+# ~/.dzil/config.ini to suppress this message in the future.
+# END_WARN
         return $_[2]->{assembler}->sequence
       },
     });
@@ -73,7 +66,8 @@ Your global configuration file couldn't be loaded.  It's a file matching
 
 You can try deleting the file or you might need to upgrade from pre-version 4
 format.  In most cases, this will just mean replacing [!release] with [%PAUSE]
-and deleting any [!new] stanza.
+and deleting any [!new] stanza.  You can also delete the existing file and run
+"dzil setup"
 END_DIE
   };
 
@@ -116,10 +110,17 @@ sub zilla {
 
     my $core_debug = grep { m/\A[-_]\z/ } @v_plugins;
 
-    my $zilla = Dist::Zilla::Dist::Builder->from_config({
-      chrome => $self->chrome,
-      _global_stashes => $self->_build_global_stashes,
-    });
+    my $zilla;
+    try {
+      $zilla = Dist::Zilla::Dist::Builder->from_config({
+        chrome => $self->chrome,
+        _global_stashes => $self->_build_global_stashes,
+      });
+    } catch {
+      die $_ unless try { $_->isa('Config::MVP::Error') }
+                 && $_->ident =~ /no viable config/;
+      $self->chrome->logger->log_fatal("no configuration (e.g, dist.ini) found");
+    };
 
     $zilla->logger->set_debug($verbose ? 1 : 0);
 
@@ -140,15 +141,18 @@ sub zilla {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::App - Dist::Zilla's App::Cmd
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 METHODS
 
@@ -163,10 +167,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
