@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 package Dist::Zilla::App::Command::install;
-BEGIN {
-  $Dist::Zilla::App::Command::install::VERSION = '4.101800';
+{
+  $Dist::Zilla::App::Command::install::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: install your dist
 use Dist::Zilla::App -command;
@@ -28,15 +28,18 @@ sub execute {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::App::Command::install - install your dist
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 SYNOPSIS
 
@@ -59,9 +62,9 @@ Any value that works with L<C<system>|perlfunc/system> is accepted.
 
 If not specified, calls (roughly):
 
-    perl -MCPAN -einstall "."
+    cpanm .
 
-For more information, look at the L<install|Dist::Zilla/install> method in
+For more information, look at the L<install|Dist::Zilla::Dist::Builder/install> method in
 Dist::Zilla.
 
 =head1 AUTHOR
@@ -70,10 +73,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
