@@ -1,17 +1,13 @@
 use strict;
 use warnings;
 package Dist::Zilla::App::Command::new;
-BEGIN {
-  $Dist::Zilla::App::Command::new::VERSION = '4.101800';
+{
+  $Dist::Zilla::App::Command::new::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: mint a new dist
 use Dist::Zilla::App -command;
 
 
-use MooseX::Types::Perl qw(DistName ModuleName);
-use Moose::Autobox;
-use Path::Class;
-
 sub abstract { 'mint a new dist' }
 
 sub usage_desc { '%c %o <ModuleName>' }
@@ -29,14 +25,17 @@ sub opt_spec {
 sub validate_args {
   my ($self, $opt, $args) = @_;
 
+  require MooseX::Types::Perl;
+
   $self->usage_error('dzil new takes exactly one argument') if @$args != 1;
 
   my $name = $args->[0];
 
-  $name =~ s/::/-/g if is_ModuleName($name) and not is_DistName($name);
+  $name =~ s/::/-/g if MooseX::Types::Perl::is_ModuleName($name)
+               and not MooseX::Types::Perl::is_DistName($name);
 
   $self->usage_error("$name is not a valid distribution name")
-    unless is_DistName($name);
+    unless MooseX::Types::Perl::is_DistName($name);
 
   $args->[0] = $name;
 }
@@ -64,15 +63,18 @@ sub execute {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::App::Command::new - mint a new dist
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 SYNOPSIS
 
@@ -105,10 +107,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
