@@ -1,15 +1,14 @@
 use strict;
 use warnings;
 package Dist::Zilla::App::Command::setup;
-BEGIN {
-  $Dist::Zilla::App::Command::setup::VERSION = '4.101800';
+{
+  $Dist::Zilla::App::Command::setup::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: set up a basic global config file
 use Dist::Zilla::App -command;
 
 
 use autodie;
-use Path::Class;
 
 sub abstract { 'set up a basic global config file' }
 
@@ -24,13 +23,15 @@ sub execute {
 
   my $chrome = $self->app->chrome;
 
-  my $config_root = $self->app->_config_root;
+  my $config_root = Dist::Zilla::Util->_global_config_root;
 
   if (
-    my @files = grep { -f and $_->basename =~ /\Aconfig\./ }
+    -d $config_root
+    and
+    my @files = grep { -f and $_->basename =~ /\Aconfig\.[^.]+\z/ }
     $config_root->children
   ) {
-    $chrome->log_fatal([
+    $chrome->logger->log_fatal([
       "per-user configuration files already exist in %s: %s",
       "$config_root",
       join(q{, }, @files),
@@ -102,7 +103,10 @@ sub execute {
   }
 
   $config_root->mkpath unless -d $config_root;
-  open my $fh, '>', $config_root->file('config.ini');
+
+  my $umask = umask;
+  umask( $umask | 077 ); # this file might contain PAUSE pw; make it go-r
+  open my $fh, '>:encoding(UTF-8)', $config_root->file('config.ini');
 
   $fh->print("[%User]\n");
   $fh->print("name  = $realname\n");
@@ -123,21 +127,26 @@ sub execute {
 
   close $fh;
 
+  umask $umask;
+
   $self->log("config.ini file created!");
 }
 
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::App::Command::setup - set up a basic global config file
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 SYNOPSIS
 
@@ -155,10 +164,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
