@@ -1,6 +1,6 @@
 package Dist::Zilla::Dist::Builder;
-BEGIN {
-  $Dist::Zilla::Dist::Builder::VERSION = '4.101800';
+{
+  $Dist::Zilla::Dist::Builder::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: dist zilla subclass for building dists
 use Moose 0.92; # role composition fixes
@@ -10,9 +10,9 @@ use Moose::Autobox 0.09; # ->flatten
 use MooseX::Types::Moose qw(HashRef);
 use MooseX::Types::Path::Class qw(Dir File);
 
-use Archive::Tar;
 use File::pushd ();
 use Path::Class;
+use Try::Tiny;
 
 use namespace::autoclean;
 
@@ -45,7 +45,30 @@ sub _setup_default_plugins {
       plugin_name => ':InstallModules',
       zilla       => $self,
       style       => 'grep',
-      code        => sub { local $_ = $_->name; m{\Alib/} and m{\.(pm|pod)$} },
+      code        => sub {
+        my ($file, $self) = @_;
+        local $_ = $file->name;
+        return 1 if m{\Alib/} and m{\.(pm|pod)$};
+        return 1 if $_ eq $self->zilla->main_module;
+        return;
+      },
+    });
+
+    $self->plugins->push($plugin);
+  }
+
+  unless ($self->plugin_named(':IncModules')) {
+    require Dist::Zilla::Plugin::FinderCode;
+    my $plugin = Dist::Zilla::Plugin::FinderCode->new({
+      plugin_name => ':IncModules',
+      zilla       => $self,
+      style       => 'grep',
+      code        => sub {
+        my ($file, $self) = @_;
+        local $_ = $file->name;
+        return 1 if m{\Ainc/} and m{\.pm$};
+        return;
+      },
     });
 
     $self->plugins->push($plugin);
@@ -107,6 +130,23 @@ sub _setup_default_plugins {
 
     $self->plugins->push($plugin);
   }
+
+  unless ($self->plugin_named(':MainModule')) {
+    require Dist::Zilla::Plugin::FinderCode;
+    my $plugin = Dist::Zilla::Plugin::FinderCode->new({
+      plugin_name => ':MainModule',
+      zilla       => $self,
+      style       => 'grep',
+      code        => sub {
+        my ($file, $self) = @_;
+        local $_ = $file->name;
+        return 1 if $_ eq $self->zilla->main_module->name;
+        return;
+      },
+    });
+
+    $self->plugins->push($plugin);
+  }
 }
 
 has _share_dir_map => (
@@ -151,7 +191,7 @@ sub _load_config {
   my $config_class =
     $arg->{config_class} ||= 'Dist::Zilla::MVP::Reader::Finder';
 
-  Class::MOP::load_class($config_class);
+  Class::Load::load_class($config_class);
 
   $arg->{chrome}->logger->log_debug(
     { prefix => '[DZ] ' },
@@ -175,12 +215,34 @@ sub _load_config {
       if $arg->{_global_stashes};
   }
 
-  my $seq = $config_class->read_config(
-    $root->file('dist'),
-    {
-      assembler => $assembler
-    },
-  );
+  my $seq;
+  try {
+    $seq = $config_class->read_config(
+      $root->file('dist'),
+      {
+        assembler => $assembler
+      },
+    );
+  } catch {
+    die $_ unless try {
+      $_->isa('Config::MVP::Error')
+      and $_->ident eq 'package not installed'
+    };
+
+    my $package = $_->package;
+
+    my $bundle = $package =~ /^@/ ? ' bundle' : '';
+    die <<"END_DIE";
+Required plugin$bundle $package isn't installed.
+
+Run 'dzil authordeps' to see a list of all required plugins.
+You can pipe the list to your CPAN client to install or update them:
+
+    dzil authordeps | cpanm
+
+END_DIE
+
+  };
 
   return $seq;
 }
@@ -201,9 +263,10 @@ sub build_in {
 
   $self->log("beginning to build " . $self->name);
 
-  $_->gather_files     for $self->plugins_with(-FileGatherer)->flatten;
-  $_->prune_files      for $self->plugins_with(-FilePruner)->flatten;
-  $_->munge_files      for $self->plugins_with(-FileMunger)->flatten;
+  $_->gather_files       for $self->plugins_with(-FileGatherer)->flatten;
+  $_->set_file_encodings for $self->plugins_with(-EncodingProvider)->flatten;
+  $_->prune_files        for $self->plugins_with(-FilePruner)->flatten;
+  $_->munge_files        for $self->plugins_with(-FileMunger)->flatten;
 
   $_->register_prereqs for $self->plugins_with(-PrereqSource)->flatten;
 
@@ -254,36 +317,44 @@ sub ensure_built_in {
 }
 
 
-sub build_archive {
-  my ($self, $file) = @_;
-
-  my $built_in = $self->ensure_built;
-
-  my $archive = Archive::Tar->new;
-
-  $_->before_archive for $self->plugins_with(-BeforeArchive)->flatten;
-
-  my %seen_dir;
-  for my $distfile ($self->files->flatten) {
-    my $in = file($distfile->name)->dir;
-    $archive->add_files( $built_in->subdir($in) ) unless $seen_dir{ $in }++;
-    $archive->add_files( $built_in->file( $distfile->name ) );
-  }
-
-  ## no critic
-  $file ||= file(join(q{},
+sub dist_basename {
+  my ($self) = @_;
+  return join(q{},
     $self->name,
     '-',
     $self->version,
-    ($self->is_trial ? '-TRIAL' : ''),
-    '.tar.gz',
-  ));
+  );
+}
 
-  # Fix up the CHMOD on the archived files, to inhibit 'withoutworldwritables'
-  # behaviour on win32.
-  for my $f ( $archive->get_files ) {
-    $f->mode( $f->mode & ~022 );
-  }
+
+sub archive_filename {
+  my ($self) = @_;
+  return join(q{},
+    $self->dist_basename,
+    ( $self->is_trial ? '-TRIAL' : '' ),
+    '.tar.gz'
+  );
+}
+
+
+sub build_archive {
+  my ($self) = @_;
+
+  my $built_in = $self->ensure_built;
+
+  my $basename = $self->dist_basename;
+  my $basedir = dir($basename);
+
+  $_->before_archive for $self->plugins_with(-BeforeArchive)->flatten;
+
+  my $method = Class::Load::load_optional_class('Archive::Tar::Wrapper',
+                                                { -version => 0.15 })
+             ? '_build_archive_with_wrapper'
+             : '_build_archive';
+
+  my $archive = $self->$method($built_in, $basename, $basedir);
+
+  my $file = file($self->archive_filename);
 
   $self->log("writing archive to $file");
   $archive->write("$file", 9);
@@ -291,11 +362,71 @@ sub build_archive {
   return $file;
 }
 
+sub _build_archive {
+  my ($self, $built_in, $basename, $basedir) = @_;
+
+  $self->log("building archive with Archive::Tar; install Archive::Tar::Wrapper 0.15 or newer for improved speed");
+
+  require Archive::Tar;
+  my $archive = Archive::Tar->new;
+  my %seen_dir;
+  for my $distfile (
+    sort { length($a->name) <=> length($b->name) } $self->files->flatten
+  ) {
+    my $in = file($distfile->name)->dir;
+
+    unless ($seen_dir{ $in }++) {
+      $archive->add_data(
+        $basedir->subdir($in),
+        '',
+        { type => Archive::Tar::Constant::DIR(), mode => 0755 },
+      )
+    }
+
+    my $filename = $built_in->file( $distfile->name );
+    my $content = do {
+      use autodie;
+      local $/;
+      open my $fh, '<', $filename;
+      <$fh>;
+    };
+    $archive->add_data(
+      $basedir->file( $distfile->name ),
+      $content,
+      { mode => (stat $filename)[2] & ~022 },
+    );
+  }
+
+  return $archive;
+}
+
+sub _build_archive_with_wrapper {
+  my ($self, $built_in, $basename, $basedir) = @_;
+
+  $self->log("building archive with Archive::Tar::Wrapper");
+
+  my $archive = Archive::Tar::Wrapper->new;
+
+  for my $distfile (
+    sort { length($a->name) <=> length($b->name) } $self->files->flatten
+  ) {
+    my $in = file($distfile->name)->dir;
+
+    my $filename = $built_in->file( $distfile->name );
+    $archive->add(
+      $basedir->file( $distfile->name )->stringify,
+      $filename->stringify,
+      { perm => (stat $filename)[2] & ~022 },
+    );
+  }
+
+  return $archive;
+}
+
 sub _prep_build_root {
   my ($self, $build_root) = @_;
 
-  my $default_name = $self->name . q{-} . $self->version;
-  $build_root = dir($build_root || $default_name);
+  $build_root = dir($build_root || $self->dist_basename);
 
   $build_root->mkpath unless -d $build_root;
 
@@ -313,6 +444,8 @@ sub release {
   Carp::croak("you can't release without any Releaser plugins")
     unless my @releasers = $self->plugins_with(-Releaser)->flatten;
 
+  $ENV{DZIL_RELEASING} = 1;
+
   my $tgz = $self->build_archive;
 
   # call all plugins implementing BeforeRelease role
@@ -327,19 +460,22 @@ sub release {
 
 
 sub clean {
-  my ($self) = @_;
+  my ($self, $dry_run) = @_;
 
   require File::Path;
   for my $x (grep { -e } '.build', glob($self->name . '-*')) {
-    $self->log("clean: removing $x");
-    File::Path::rmtree($x);
+    if ($dry_run) {
+      $self->log("clean: would remove $x");
+    } else {
+      $self->log("clean: removing $x");
+      File::Path::rmtree($x);
+    }
   };
 }
 
 
-sub install {
-  my ($self, $arg) = @_;
-  $arg ||= {};
+sub ensure_built_in_tmpdir {
+  my $self = shift;
 
   require File::Temp;
 
@@ -348,15 +484,44 @@ sub install {
 
   my $target = dir( File::Temp::tempdir(DIR => $build_root) );
   $self->log("building distribution under $target for installation");
+
+  my $os_has_symlinks = eval { symlink("",""); 1 };
+  my $previous;
+  my $latest;
+
+  if( $os_has_symlinks ) {
+    $previous = file( $build_root, 'previous' );
+    $latest   = file( $build_root, 'latest'   );
+    if( -l $previous ) {
+      $previous->remove
+        or $self->log("cannot remove old .build/previous link");
+    }
+    if( -l $latest ) {
+      rename $latest, $previous
+        or $self->log("cannot move .build/latest link to .build/previous");
+    }
+    symlink $target->basename, $latest
+      or $self->log('cannot create link .build/latest');
+  }
+
   $self->ensure_built_in($target);
 
+  return ($target, $latest, $previous);
+}
+
+
+sub install {
+  my ($self, $arg) = @_;
+  $arg ||= {};
+
+  my ($target, $latest) = $self->ensure_built_in_tmpdir;
+
   eval {
     ## no critic Punctuation
     my $wd = File::pushd::pushd($target);
     my @cmd = $arg->{install_command}
             ? @{ $arg->{install_command} }
-            : ($^X => '-MCPAN' =>
-                $^O eq 'MSWin32' ? q{-e"install '.'"} : '-einstall "."');
+            : (cpanm => ".");
 
     $self->log_debug([ 'installing via %s', \@cmd ]);
     system(@cmd) && $self->log_fatal([ "error running %s", \@cmd ]);
@@ -368,6 +533,7 @@ sub install {
   } else {
     $self->log("all's well; removing $target");
     $target->rmtree;
+    $latest->remove if $latest;
   }
 
   return;
@@ -380,23 +546,12 @@ sub test {
   Carp::croak("you can't test without any TestRunner plugins")
     unless my @testers = $self->plugins_with(-TestRunner)->flatten;
 
-  require File::Temp;
-
-  my $build_root = dir('.build');
-  $build_root->mkpath unless -d $build_root;
-
-  my $target = dir( File::Temp::tempdir(DIR => $build_root) );
-  $self->log("building test distribution under $target");
-
-  local $ENV{AUTHOR_TESTING} = 1;
-  local $ENV{RELEASE_TESTING} = 1;
-
-  $self->ensure_built_in($target);
-
-  my $error = $self->run_tests_in($target);
+  my ($target, $latest) = $self->ensure_built_in_tmpdir;
+  my $error  = $self->run_tests_in($target);
 
   $self->log("all's well; removing $target");
   $target->rmtree;
+  $latest->remove if $latest;
 }
 
 
@@ -423,25 +578,23 @@ sub run_in_build {
     $self->plugins_with(-BuildRunner)->sort->reverse->flatten;
 
   require "Config.pm"; # skip autoprereq
-  require File::Temp;
 
-  # dzil-build the dist
-  my $build_root = dir('.build');
-  $build_root->mkpath unless -d $build_root;
-
-  my $target    = dir( File::Temp::tempdir(DIR => $build_root) );
+  my ($target, $latest) = $self->ensure_built_in_tmpdir;
   my $abstarget = $target->absolute;
-  $self->log("building test distribution under $target");
-
-  $self->ensure_built_in($target);
 
   # building the dist for real
   my $ok = eval {
     my $wd = File::pushd::pushd($target);
     $builders[0]->build;
-    local $ENV{PERL5LIB} =
-      join $Config::Config{path_sep},
-      map { $abstarget->subdir('blib', $_) } qw{ arch lib };
+
+    local $ENV{PERL5LIB} = join $Config::Config{path_sep},
+      (map { $abstarget->subdir('blib', $_) } qw(arch lib)),
+      (defined $ENV{PERL5LIB} ? $ENV{PERL5LIB} : ());
+
+    local $ENV{PATH} = join $Config::Config{path_sep},
+      (map { $abstarget->subdir('blib', $_) } qw(bin script)),
+      (defined $ENV{PATH} ? $ENV{PATH} : ());
+
     system(@$cmd) and die "error while running: @$cmd";
     1;
   };
@@ -449,6 +602,7 @@ sub run_in_build {
   if ($ok) {
     $self->log("all's well; removing $target");
     $target->rmtree;
+    $latest->remove if $latest;
   } else {
     my $error = $@ || '(unknown error)';
     $self->log($error);
@@ -460,15 +614,18 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Dist::Builder - dist zilla subclass for building dists
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 ATTRIBUTES
 
@@ -514,12 +671,28 @@ for the preposition!
 This method behaves like C<L</build_in>>, but if the dist is already built in
 C<$root> (or the default root, if no root is given), no exception is raised.
 
-=head2 ensure_built_in
+=head2 ensure_built
 
 This method just calls C<ensure_built_in> with no arguments.  It gets you the
 default behavior without the weird-looking formulation of C<ensure_built_in>
 with no object for the preposition!
 
+=head2 dist_basename
+
+  my $basename = $zilla->dist_basename;
+
+This method will return the dist's basename (e.g. C<Dist-Name-1.01>.
+The basename is used as the top-level directory in the tarball.  It
+does not include C<-TRIAL>, even if building a trial dist.
+
+=head2 archive_filename
+
+  my $tarball = $zilla->archive_filename;
+
+This method will return the filename (e.g. C<Dist-Name-1.01.tar.gz>)
+of the tarball of this dist.  It will include C<-TRIAL> if building a
+trial dist.  The tarball might not exist.
+
 =head2 build_archive
 
   $zilla->build_archive;
@@ -542,6 +715,13 @@ produced by the Dist::Zilla build process.  Specifically, it deletes the
 F<.build> directory and any entity that starts with the dist name and a hyphen,
 like matching the glob C<Your-Dist-*>.
 
+=head2 ensure_built_in_tmpdir
+
+  $zilla->ensure_built_in_tmpdir;
+
+This method will consistently build the distribution in a temporary
+subdirectory. It will return the path for the temporary build location.
+
 =head2 install
 
   $zilla->install( \%arg );
@@ -590,10 +770,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
