@@ -1,12 +1,14 @@
 package Dist::Zilla::MVP::Assembler;
-BEGIN {
-  $Dist::Zilla::MVP::Assembler::VERSION = '4.101800';
+{
+  $Dist::Zilla::MVP::Assembler::VERSION = '5.000'; # TRIAL
 }
 use Moose;
 extends 'Config::MVP::Assembler';
 with 'Config::MVP::Assembler::WithBundles';
 # ABSTRACT: Dist::Zilla-specific subclass of Config::MVP::Assembler
 
+use namespace::autoclean;
+
 use Dist::Zilla::Util;
 
 
@@ -48,19 +50,22 @@ before add_value => sub {
   );
 };
 
-no Moose;
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::MVP::Assembler - Dist::Zilla-specific subclass of Config::MVP::Assembler
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -88,10 +93,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
