@@ -1,11 +1,13 @@
 package Dist::Zilla::MVP::Assembler::Zilla;
-BEGIN {
-  $Dist::Zilla::MVP::Assembler::Zilla::VERSION = '4.101800';
+{
+  $Dist::Zilla::MVP::Assembler::Zilla::VERSION = '5.000'; # TRIAL
 }
 use Moose;
 extends 'Dist::Zilla::MVP::Assembler';
 # ABSTRACT: Dist::Zilla::MVP::Assembler for the Dist::Zilla object
 
+use namespace::autoclean;
+
 
 use MooseX::Types::Perl qw(PackageName);
 use Dist::Zilla::MVP::RootSection;
@@ -18,9 +20,9 @@ sub BUILD {
 }
 
 has zilla_class => (
-  is      => 'ro',
-  isa     => PackageName,
-  default => 'Dist::Zilla',
+  is       => 'ro',
+  isa      => PackageName,
+  required => 1
 );
 
 
@@ -39,19 +41,22 @@ sub register_stash {
   return;
 }
 
-no Moose;
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::MVP::Assembler::Zilla - Dist::Zilla::MVP::Assembler for the Dist::Zilla object
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 OVERVIEW
 
@@ -86,10 +91,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
