@@ -1,12 +1,14 @@
 package Dist::Zilla::MVP::Reader::Perl;
-BEGIN {
-  $Dist::Zilla::MVP::Reader::Perl::VERSION = '4.101800';
+{
+  $Dist::Zilla::MVP::Reader::Perl::VERSION = '5.000'; # TRIAL
 }
 use Moose;
 extends 'Config::MVP::Reader';
 with qw(Config::MVP::Reader::Findable::ByExtension);
 # ABSTRACT: the reader for dist.pl files
 
+use namespace::autoclean;
+
 
 sub default_extension { 'pl' }
 
@@ -43,20 +45,22 @@ sub read_into_assembler {
   return $self->assembler->sequence;
 }
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::MVP::Reader::Perl - the reader for dist.pl files
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -68,10 +72,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
