@@ -1,11 +1,15 @@
 package Dist::Zilla::MVP::Section;
-BEGIN {
-  $Dist::Zilla::MVP::Section::VERSION = '4.101800';
+{
+  $Dist::Zilla::MVP::Section::VERSION = '5.000'; # TRIAL
 }
 use Moose;
 extends 'Config::MVP::Section';
 # ABSTRACT: a standard section in Dist::Zilla's configuration sequence
 
+use namespace::autoclean;
+
+use Config::MVP::Section 2.200002; # for not-installed error
+
 use Moose::Autobox;
 
 after finalize => sub {
@@ -23,41 +27,33 @@ after finalize => sub {
   $dzil{$_} = delete $payload{":$_"} for grep { s/\A:// } keys %payload;
 
   if (defined $dzil{version}) {
-    require Version::Requirements;
-    my $req = Version::Requirements->from_string_hash({
-      $plugin_class => $dzil{version}
-    });
-
-    my $version = $plugin_class->VERSION;
-    unless ($req->accepts_module($plugin_class => $version)) {
-      # $self->assembler->log_fatal([
-      confess sprintf
-        "%s version (%s) not match required version: %s",
-        $plugin_class,
-        $version,
-        $dzil{version},
-      ;
-      # ]);
-    }
+    Dist::Zilla::Util->_assert_loaded_class_version_ok(
+      $plugin_class,
+      $dzil{version},
+    );
   }
 
-  $plugin_class->register_component($name, $arg, $self);
+  $plugin_class->register_component($name, \%payload, $self);
 
   return;
 };
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::MVP::Section - a standard section in Dist::Zilla's configuration sequence
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 AUTHOR
 
@@ -65,10 +61,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
