@@ -1,42 +1,49 @@
 package Dist::Zilla::MintingProfile::Default;
-BEGIN {
-  $Dist::Zilla::MintingProfile::Default::VERSION = '4.101800';
+{
+  $Dist::Zilla::MintingProfile::Default::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: Default minting profile provider
 use Moose;
 with 'Dist::Zilla::Role::MintingProfile::ShareDir';
 
-use File::HomeDir ();
-use Path::Class;
-
 use namespace::autoclean;
 
+use Dist::Zilla::Util;
+use Path::Class;
+
 
 around profile_dir => sub {
   my ($orig, $self, $profile_name) = @_;
 
   $profile_name ||= 'default';
 
-  my $profile_dir = dir( File::HomeDir->my_home )
-                  ->subdir('.dzil', 'profiles', $profile_name);
+  # shouldn't look in user's config when testing
+  if (!$ENV{DZIL_TESTING}) {
+    my $profile_dir = Dist::Zilla::Util->_global_config_root
+                    ->subdir('profiles', $profile_name);
 
-  return $profile_dir if -d $profile_dir;
+    return $profile_dir if -d $profile_dir;
+  }
 
   return $self->$orig($profile_name);
 };
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::MintingProfile::Default - Default minting profile provider
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -51,10 +58,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
