@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::AutoVersion;
-BEGIN {
-  $Dist::Zilla::Plugin::AutoVersion::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::AutoVersion::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: take care of numbering versions so you don't have to
 use Moose;
@@ -9,6 +9,8 @@ with(
   'Dist::Zilla::Role::TextTemplate',
 );
 
+use namespace::autoclean;
+
 use DateTime 0.44 (); # CLDR fixes
 
 
@@ -56,19 +58,21 @@ sub provide_version {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::AutoVersion - take care of numbering versions so you don't have to
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -98,16 +102,26 @@ The default value is:
   {{ sprintf('%01u', ($ENV{N} || 0)) }}
   {{$ENV{DEV} ? (sprintf '_%03u', $ENV{DEV}) : ''}}
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins:
+L<PkgVersion|Dist::Zilla::Plugin::PkgVersion>,
+L<PodVersion|Dist::Zilla::Plugin::PodVersion>,
+L<NextRelease|Dist::Zilla::Plugin::NextRelease>.
+
+Dist::Zilla roles:
+L<VersionProvider|Dist::Zilla::Role::VersionProvider>,
+L<TextTemplate|Dist::Zilla::Role::TextTemplate>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
