@@ -1,18 +1,23 @@
 package Dist::Zilla::Plugin::ConfirmRelease;
-BEGIN {
-  $Dist::Zilla::Plugin::ConfirmRelease::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::ConfirmRelease::VERSION = '5.000'; # TRIAL
 }
-# ABSTRACT: prompt for confirmation before releasing
-
-use ExtUtils::MakeMaker ();
-
 use Moose;
 with 'Dist::Zilla::Role::BeforeRelease';
+# ABSTRACT: prompt for confirmation before releasing
+
+use namespace::autoclean;
+
+use Moose::Autobox;
 
 sub before_release {
   my ($self, $tgz) = @_;
 
-  my $prompt = "*** Preparing to upload $tgz to CPAN ***\n"
+  my $releasers = join q{, },
+                  map {; $_->plugin_name }
+                  $self->zilla->plugins_with(-Releaser)->flatten;
+
+  my $prompt = "*** Preparing to release $tgz with $releasers ***\n"
              . "Do you want to continue the release process?";
 
   my $default = exists $ENV{DZIL_CONFIRMRELEASE_DEFAULT}
@@ -27,21 +32,22 @@ sub before_release {
   $self->log_fatal("Aborting release") unless $confirmed;
 }
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::ConfirmRelease - prompt for confirmation before releasing
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -53,23 +59,15 @@ The default is "no", but you can set the environment variable
 C<DZIL_CONFIRMRELEASE_DEFAULT> to "yes" if you just want to hit enter to
 release.
 
-This plugin uses C<ExtUtils::MakeMaker::prompt()>, so setting
-C<PERL_MM_USE_DEFAULT> to a true value will accept the default without
-prompting.
-
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
