@@ -1,10 +1,12 @@
 package Dist::Zilla::Plugin::ExecDir;
-BEGIN {
-  $Dist::Zilla::Plugin::ExecDir::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::ExecDir::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: install a directory's contents as executables
 use Moose;
 
+use namespace::autoclean;
+
 use Moose::Autobox;
 
 
@@ -23,19 +25,21 @@ sub find_files {
 
 with 'Dist::Zilla::Role::ExecFiles';
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::ExecDir - install a directory's contents as executables
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 SYNOPSIS
 
@@ -44,16 +48,17 @@ In your F<dist.ini>:
   [ExecDir]
   dir = scripts
 
+If no C<dir> is provided, the default is F<bin>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
