@@ -1,11 +1,13 @@
 package Dist::Zilla::Plugin::ExtraTests;
-BEGIN {
-  $Dist::Zilla::Plugin::ExtraTests::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::ExtraTests::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: rewrite ./xt tests to ./t tests with skips
 use Moose;
 with 'Dist::Zilla::Role::FileMunger';
 
+use namespace::autoclean;
+
 
 sub munge_file {
   my ($self, $file) = @_;
@@ -55,19 +57,21 @@ BEGIN {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::ExtraTests - rewrite ./xt tests to ./t tests with skips
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -87,10 +91,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
