@@ -1,12 +1,14 @@
 package Dist::Zilla::Plugin::FakeRelease;
-BEGIN {
-  $Dist::Zilla::Plugin::FakeRelease::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::FakeRelease::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: fake plugin to test release
 
 use Moose;
 with 'Dist::Zilla::Role::Releaser';
 
+use namespace::autoclean;
+
 has user => (
   is   => 'ro',
   isa  => 'Str',
@@ -27,21 +29,22 @@ sub release {
   $self->log('Fake release happening (nothing was really done)');
 }
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::FakeRelease - fake plugin to test release
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 SYNOPSIS
 
@@ -50,34 +53,37 @@ version 4.101800
 
 =head1 DESCRIPTION
 
-This plugin is a C<Releaser> that does nothing. It is directed to plugin
-authors, who may need a dumb release plugin to test their shiny plugin
-implementing C<BeforeRelease> and C<AfterRelease>.
+This plugin is a L<Releaser|Dist::Zilla::Role::Releaser> that does nothing. It
+is directed to plugin authors, who may need a dumb release plugin to test their
+shiny plugin implementing L<BeforeRelease|Dist::Zilla::Role::BeforeRelease>
+and L<AfterRelease|Dist::Zilla::Role::AfterRelease>.
 
 When this plugin does the release, it will just log a message and finish.
 
 If you set the environment variable C<DZIL_FAKERELEASE_FAIL> to a true value,
-the plugin will die instead of doing nothing. This can be usefulfor
+the plugin will die instead of doing nothing. This can be useful for
 authors wanting to test reliably that release failed.
 
 You can optionally provide the 'user' parameter, which defaults to 'AUTHORID',
 which will allow things that depend on this metadata
-( Sometimes provided by L<Dist::Zilla::Plugin::UploadToCPAN> ) to still work.
+( Sometimes provided by L<UploadToCPAN|Dist::Zilla::Plugin::UploadToCPAN> ) to still work.
 ( For example: L<Dist::Zilla::Plugin::Twitter> )
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins:
+L<ConfirmRelease|Dist::Zilla::Plugin::ConfirmRelease>,
+L<UploadToCPAN|Dist::Zilla::Plugin::UploadToCPAN>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
