@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GatherDir;
-BEGIN {
-  $Dist::Zilla::Plugin::GatherDir::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::GatherDir::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: gather all the files in a directory
 use Moose;
@@ -8,6 +8,8 @@ use Moose::Autobox;
 use MooseX::Types::Path::Class qw(Dir File);
 with 'Dist::Zilla::Role::FileGatherer';
 
+use namespace::autoclean;
+
 
 use File::Find::Rule;
 use File::HomeDir;
@@ -40,31 +42,62 @@ has include_dotfiles => (
   default => 0,
 );
 
+
+has follow_symlinks => (
+  is  => 'ro',
+  isa => 'Bool',
+  default => 0,
+);
+
+sub mvp_multivalue_args { qw(exclude_filename exclude_match) }
+
+
+has exclude_filename => (
+  is   => 'ro',
+  isa  => 'ArrayRef',
+  default => sub { [] },
+);
+
+
+has exclude_match => (
+  is   => 'ro',
+  isa  => 'ArrayRef',
+  default => sub { [] },
+);
+
 sub gather_files {
   my ($self) = @_;
 
+  my $exclude_regex = qr/\000/;
+  $exclude_regex = qr/$exclude_regex|$_/
+    for ($self->exclude_match->flatten);
+
+  my %is_excluded = map {; $_ => 1 } $self->exclude_filename->flatten;
+
   my $root = "" . $self->root;
   $root =~ s{^~([\\/])}{File::HomeDir->my_home . $1}e;
   $root = Path::Class::dir($root);
 
-  my @files;
-  FILE: for my $filename (File::Find::Rule->file->in($root)) {
+  my $rule = File::Find::Rule->new();
+  $rule->extras({follow => $self->follow_symlinks});
+  FILE: for my $filename ($rule->file->in($root)) {
+    my $file = file($filename)->relative($root);
+
     unless ($self->include_dotfiles) {
-      my $file = file($filename)->relative($root);
       next FILE if $file->basename =~ qr/^\./;
       next FILE if grep { /^\.[^.]/ } $file->dir->dir_list;
     }
 
-    push @files, $self->_file_from_filename($filename);
-  }
+    next if $file =~ $exclude_regex;
+    next if $is_excluded{ $file };
 
-  for my $file (@files) {
-    (my $newname = $file->name) =~ s{\A\Q$root\E[\\/]}{}g;
-    $newname = File::Spec->catdir($self->prefix, $newname) if $self->prefix;
-    $newname = Path::Class::dir($newname)->as_foreign('Unix')->stringify;
+    # _file_from_filename is overloaded in GatherDir::Template
+    my $fileobj = $self->_file_from_filename($filename);
 
-    $file->name($newname);
-    $self->add_file($file);
+    $file = Path::Class::file($self->prefix, $file) if $self->prefix;
+
+    $fileobj->name($file->as_foreign('Unix')->stringify);
+    $self->add_file($fileobj);
   }
 
   return;
@@ -80,19 +113,21 @@ sub _file_from_filename {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::GatherDir - gather all the files in a directory
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -139,16 +174,32 @@ both for files and for directories relative to the C<root>.
 
 In almost all cases, the default value (false) is correct.
 
+=head2 follow_symlinks
+
+By default, directories that are symlinks will not be followed. Note on the
+other hand that in all followed directories, files which are symlinks are
+always gathered.
+
+=head2 exclude_filename
+
+To exclude certain files from being gathered, use the C<exclude_filename>
+option. This may be used multiple times to specify multiple files to exclude.
+
+=head2 exclude_match
+
+This is just like C<exclude_filename> but provides a regular expression
+pattern.  Files matching the pattern are not gathered.  This may be used
+multiple times to specify multiple patterns to exclude.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
