@@ -1,16 +1,17 @@
 package Dist::Zilla::Plugin::GatherDir::Template;
-BEGIN {
-  $Dist::Zilla::Plugin::GatherDir::Template::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::GatherDir::Template::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: gather all the files in a directory and use them as templates
 use Moose;
 extends 'Dist::Zilla::Plugin::GatherDir';
 with 'Dist::Zilla::Role::TextTemplate';
 
+use namespace::autoclean;
+
 use autodie;
 use Moose::Autobox;
 use Dist::Zilla::File::FromCode;
-use namespace::autoclean;
 
 
 sub _file_from_filename {
@@ -24,7 +25,7 @@ sub _file_from_filename {
 
   return Dist::Zilla::File::FromCode->new({
     name => $filename,
-    mode => (stat $filename)[2] & 0755, # kill world-writeability
+    mode => ((stat $filename)[2] & 0755) | 0200, # kill world-writeability, make sure owner-writable.
     code => sub {
       my ($file_obj) = @_;
       $self->fill_in_string(
@@ -39,26 +40,31 @@ sub _file_from_filename {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::GatherDir::Template - gather all the files in a directory and use them as templates
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
-This is a very, very simple L<FileGatherer|Dist::Zilla::FileGatherer> plugin.
-It looks in the directory named in the L</root> attribute and adds all the
-files it finds there.  If the root begins with a tilde, the tilde is replaced
-with the current user's home directory according to L<File::HomeDir>.
+This is a subclass of the L<GatherDir|Dist::Zilla::Plugin::GatherDir>
+plugin.  It works just like its parent class, except that each
+gathered file is processed through L<Text::Template>.
+
+The variables C<$plugin> and C<$dist> will be provided to the
+template, set to the GatherDir::Template plugin and the Dist::Zilla
+object, respectively.
 
 It is meant to be used when minting dists with C<dzil new>, but could be used
 in building existing dists, too.
@@ -69,10 +75,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
