@@ -1,16 +1,22 @@
 package Dist::Zilla::Plugin::GenerateFile;
-BEGIN {
-  $Dist::Zilla::Plugin::GenerateFile::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::GenerateFile::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: build a custom file from only the plugin configuration
 use Moose;
 use Moose::Autobox;
-with 'Dist::Zilla::Role::FileGatherer';
-with 'Dist::Zilla::Role::TextTemplate';
+with (
+  'Dist::Zilla::Role::FileGatherer',
+  'Dist::Zilla::Role::TextTemplate',
+);
+
+use namespace::autoclean;
 
 use Dist::Zilla::File::InMemory;
 
 
+sub mvp_aliases { +{ is_template => 'content_is_template' } }
+
 sub mvp_multivalue_args { qw(content) }
 
 
@@ -27,7 +33,14 @@ has content => (
 );
 
 
-has is_template => (
+has content_is_template => (
+  is  => 'ro',
+  isa => 'Bool',
+  default => 0,
+);
+
+
+has name_is_template => (
   is  => 'ro',
   isa => 'Bool',
   default => 0,
@@ -36,10 +49,22 @@ has is_template => (
 sub gather_files {
   my ($self, $arg) = @_;
 
+  my $file = Dist::Zilla::File::InMemory->new({
+    name    => $self->_filename,
+    content => $self->_content,
+  });
+
+  $self->add_file($file);
+  return;
+}
+
+sub _content {
+  my $self = shift;
+
   my $content = join "\n", $self->content->flatten;
   $content .= qq{\n};
 
-  if ($self->is_template) {
+  if ($self->content_is_template) {
     $content = $self->fill_in_string(
       $content,
       {
@@ -49,37 +74,52 @@ sub gather_files {
     );
   }
 
-  my $file = Dist::Zilla::File::InMemory->new({
-    name    => $self->filename,
-    content => $content,
-  });
+  return $content;
+}
 
-  $self->add_file($file);
-  return;
+sub _filename {
+  my $self = shift;
+
+  my $filename = $self->filename;
+
+  if ($self->name_is_template) {
+    $filename = $self->fill_in_string(
+      $filename,
+      {
+        dist   => \($self->zilla),
+        plugin => \($self),
+      },
+    );
+  }
+
+  return $filename;
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::GenerateFile - build a custom file from only the plugin configuration
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 SYNOPSIS
 
 In your F<dist.ini>:
 
   [GenerateFile]
-  filename    = todo/master-plan.txt
-  is_template = 1
+  filename    = todo/{{ $dist->name =~ s/::/-/r }}_master-plan.txt
+  name_is_template = 1
+  content_is_template = 1
   content = # Outlines the plan for world domination by {{$dist->name}}
   content =
   content = Item 1: Think of an idea!
@@ -91,11 +131,17 @@ In your F<dist.ini>:
 This plugin adds a file to the distribution.
 
 You can specify the content, as a sequence of lines, in your configuration.
-The specified content might be literal, or might be a Text::Template template.
+The specified filename and content might be literals or might be Text::Template
+templates.
 
 =head2 Templating of the content
 
-If you provide a C<is_template> parameter of "1", The content will also be run
+If you provide C<content_is_template> (or C<is_template>) parameter of "1", the
+content will be run through Text::Template.  The variables C<$plugin> and
+C<$dist> will be provided, set to the GenerateFile plugin and the Dist::Zilla
+object respectively.
+
+If you provide a C<name_is_template> parameter of "1", the filename will be run
 through Text::Template.  The variables C<$plugin> and C<$dist> will be
 provided, set to the GenerateFile plugin and the Dist::Zilla object
 respectively.
@@ -111,21 +157,25 @@ This attribute names the file you want to generate.  It is required.
 The C<content> attribute is an arrayref of lines that will be joined together
 with newlines to form the file content.
 
-=head2 is_template
+=head2 content_is_template, is_template
 
 This attribute is a bool indicating whether or not the content should be
 treated as a Text::Template template.  By default, it is false.
 
+=head2 name_is_template
+
+This attribute is a bool indicating whether or not the filename should be
+treated as a Text::Template template.  By default, it is false.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
