@@ -1,14 +1,19 @@
 package Dist::Zilla::Plugin::InlineFiles;
-BEGIN {
-  $Dist::Zilla::Plugin::InlineFiles::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::InlineFiles::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: files in a data section
 use Moose;
 use Moose::Autobox;
 with 'Dist::Zilla::Role::FileGatherer';
 
+use namespace::autoclean;
 
-use Data::Section 0.004 -setup; # fixed header_re
+
+use Sub::Exporter::ForMethods;
+use Data::Section 0.200002 # encoding and bytes
+  { installer => Sub::Exporter::ForMethods::method_installer },
+  '-setup' => { encoding => 'bytes' };
 use Dist::Zilla::File::InMemory;
 
 sub gather_files {
@@ -30,19 +35,21 @@ sub gather_files {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::InlineFiles - files in a data section
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -50,16 +57,22 @@ This plugin exists only to be extended, and gathers all files contained in its
 data section and those of its ancestors.  For more information, see
 L<Data::Section|Data::Section>.
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins inheriting from L<InlineFiles>:
+L<MetaTests|Dist::Zilla::Plugin::MetaTests>,
+L<PodCoverageTests|Dist::Zilla::Plugin::PodCoverageTests>,
+L<PodSyntaxTests|Dist::Zilla::Plugin::PodSyntaxTests>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
