@@ -1,11 +1,13 @@
 package Dist::Zilla::Plugin::License;
-BEGIN {
-  $Dist::Zilla::Plugin::License::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::License::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: output a LICENSE file
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 
+use namespace::autoclean;
+
 
 use Dist::Zilla::File::InMemory;
 
@@ -22,19 +24,21 @@ sub gather_files {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::License - output a LICENSE file
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -42,16 +46,37 @@ This plugin adds a F<LICENSE> file containing the full text of the
 distribution's license, as produced by the C<fulltext> method of the
 dist's L<Software::License> object.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item *
+
+the C<license> attribute of the L<Dist::Zilla> object to select the license
+to use.
+
+=item *
+
+Dist::Zilla roles:
+L<FileGatherer|Dist::Zilla::Role::FileGatherer>.
+
+=item *
+
+Other modules:
+L<Software::License>,
+L<Software::License::Artistic_2_0>.
+
+=back
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
