@@ -1,12 +1,14 @@
 package Dist::Zilla::Plugin::Manifest;
-BEGIN {
-  $Dist::Zilla::Plugin::Manifest::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::Manifest::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: build a MANIFEST file
 use Moose;
 use Moose::Autobox;
 with 'Dist::Zilla::Role::FileGatherer';
 
+use namespace::autoclean;
+
 use Dist::Zilla::File::FromCode;
 
 
@@ -36,19 +38,21 @@ sub gather_files {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::Manifest - build a MANIFEST file
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -56,16 +60,26 @@ If included, this plugin will produce a F<MANIFEST> file for the distribution,
 listing all of the files it contains.  For obvious reasons, it should be
 included as close to last as possible.
 
+This plugin is included in the L<@Basic|Dist::Zilla::PluginBundle::Basic>
+bundle.
+
+=head1 SEE ALSO
+
+Dist::Zilla core plugins:
+L<@Basic|Dist::Zilla::PluginBundle::Manifest>,
+L<ManifestSkip|Dist::Zilla::Plugin::ManifestSkip>.
+
+Other modules: L<ExtUtils::Manifest>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
