@@ -1,11 +1,13 @@
 package Dist::Zilla::Plugin::MetaConfig;
-BEGIN {
-  $Dist::Zilla::Plugin::MetaConfig::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::MetaConfig::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: summarize Dist::Zilla configuration into distmeta
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
+use namespace::autoclean;
+
 
 sub metadata {
   my ($self) = @_;
@@ -22,6 +24,10 @@ sub metadata {
       (keys %$config ? (config => $config) : ()),
   };
 
+  $dump->{perl} = {
+    version => $],
+  };
+
   for my $plugin (@{ $self->zilla->plugins }) {
     my $config = $plugin->dump_config;
 
@@ -36,20 +42,22 @@ sub metadata {
   return { x_Dist_Zilla => $dump };
 }
 
-no Moose;
-__PACKAGE__->meta->make_immutable(inline_constructor => 0);
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::MetaConfig - summarize Dist::Zilla configuration into distmeta
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -60,16 +68,22 @@ package, and version will be included.  Plugins may augment their
 implementation of the L<Dist::Zilla::Role::ConfigDumper> role methods to add
 more data to this dump.
 
+More information may be added to the top-level of this metadata as time goes
+on.
+
+=head1 SEE ALSO
+
+Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
