@@ -1,17 +1,15 @@
 package Dist::Zilla::Plugin::MetaJSON;
-BEGIN {
-  $Dist::Zilla::Plugin::MetaJSON::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::MetaJSON::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: produce a META.json
 use Moose;
 use Moose::Autobox;
 with 'Dist::Zilla::Role::FileGatherer';
 
-use CPAN::Meta::Converter 2.101550; # improved downconversion
-use CPAN::Meta::Validator 2.101550; # improved downconversion
+use namespace::autoclean;
+
 use Dist::Zilla::File::FromCode;
-use Hash::Merge::Simple ();
-use JSON 2;
 
 
 has filename => (
@@ -32,8 +30,19 @@ sub gather_files {
 
   my $zilla = $self->zilla;
 
+  require JSON;
+  JSON->VERSION(2);
+  require CPAN::Meta::Converter;
+  CPAN::Meta::Converter->VERSION(2.101550); # improved downconversion
+  require CPAN::Meta::Validator;
+  CPAN::Meta::Validator->VERSION(2.101550); # improved downconversion
+
   my $file  = Dist::Zilla::File::FromCode->new({
     name => $self->filename,
+    # RJBS and XDG didn't 100% agree on this, it's probably fine until somebody
+    # comes up with a really good argument to change it (or to remove this
+    # comment, settling the argument). -- rjbs, 2013-10-19
+    code_return_type => 'bytes',
     code => sub {
       my $distmeta  = $zilla->distmeta;
 
@@ -57,20 +66,22 @@ sub gather_files {
   return;
 }
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::MetaJSON - produce a META.json
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -94,16 +105,28 @@ they are released and adopted.
 
 If you want a fixed version, specify it.
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins:
+L<@Basic|Dist::Zilla::PluginBundle::Basic>,
+L<Manifest|Dist::Zilla::Plugin::Manifest>.
+
+Dist::Zilla roles:
+L<FileGatherer|Dist::Zilla::Role::FileGatherer>.
+
+Other modules:
+L<CPAN::Meta>,
+L<CPAN::Meta::Spec>, L<JSON>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
