@@ -1,12 +1,14 @@
 package Dist::Zilla::Plugin::MetaResources;
-BEGIN {
-  $Dist::Zilla::Plugin::MetaResources::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::MetaResources::VERSION = '5.000'; # TRIAL
 }
 
 # ABSTRACT: provide arbitrary "resources" for distribution metadata
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
+use namespace::autoclean;
+
 
 has resources => (
   is       => 'ro',
@@ -21,6 +23,10 @@ sub BUILDARGS {
   my $zilla = delete $copy{zilla};
   my $name  = delete $copy{plugin_name};
 
+  if (exists $copy{license} && ref($copy{license}) ne 'ARRAY') {
+      $copy{license} = [ $copy{license} ];
+  }
+
   if (exists $copy{bugtracker}) {
     my $tracker = delete $copy{bugtracker};
     $copy{bugtracker}{web} = $tracker;
@@ -51,20 +57,22 @@ sub metadata {
   return { resources => $self->resources };
 }
 
-no Moose;
-__PACKAGE__->meta->make_immutable(inline_constructor => 0);
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::MetaResources - provide arbitrary "resources" for distribution metadata
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -78,16 +86,21 @@ This plugin adds resources entries to the distribution's metadata.
   repository.web    = http://github.com/dude/project
   repository.type   = git
 
+=head1 SEE ALSO
+
+Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
+
+Dist::Zilla plugins on the CPAN: L<GithubMeta|Dist::Zilla::Plugin::GithubMeta>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
