@@ -1,15 +1,14 @@
 package Dist::Zilla::Plugin::MetaYAML;
-BEGIN {
-  $Dist::Zilla::Plugin::MetaYAML::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::MetaYAML::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: produce a META.yml
 use Moose;
 use Moose::Autobox;
 with 'Dist::Zilla::Role::FileGatherer';
 
-use CPAN::Meta::Converter 2.101550; # improved downconversion
-use CPAN::Meta::Validator 2.101550; # improved downconversion
-use Hash::Merge::Simple ();
+use Try::Tiny;
+use namespace::autoclean;
 
 
 has filename => (
@@ -30,11 +29,16 @@ sub gather_files {
 
   require Dist::Zilla::File::FromCode;
   require YAML::Tiny;
+  require CPAN::Meta::Converter;
+  CPAN::Meta::Converter->VERSION(2.101550); # improved downconversion
+  require CPAN::Meta::Validator;
+  CPAN::Meta::Validator->VERSION(2.101550); # improved downconversion
 
   my $zilla = $self->zilla;
 
   my $file  = Dist::Zilla::File::FromCode->new({
     name => $self->filename,
+    code_return_type => 'text',
     code => sub {
       my $distmeta  = $zilla->distmeta;
 
@@ -48,8 +52,13 @@ sub gather_files {
 
       my $converter = CPAN::Meta::Converter->new($distmeta);
       my $output    = $converter->convert(version => $self->version);
-
-      YAML::Tiny::Dump($output);
+      my $yaml = try {
+        YAML::Tiny->new($output)->write_string; # text!
+      }
+      catch {
+        $self->log_fatal("Could not create YAML string: " . YAML::Tiny->errstr)
+      };
+      return $yaml;
     },
   });
 
@@ -57,20 +66,22 @@ sub gather_files {
   return;
 }
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::MetaYAML - produce a META.yml
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -96,16 +107,28 @@ B<This may change without notice in the future.>
 Once version 2 of the META file spec is more widely supported, this may default
 to 2.
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins:
+L<@Basic|Dist::Zilla::PluginBundle::Basic>,
+L<Manifest|Dist::Zilla::Plugin::Manifest>.
+
+Dist::Zilla roles:
+L<FileGatherer|Dist::Zilla::Role::FileGatherer>.
+
+Other modules:
+L<CPAN::Meta>,
+L<CPAN::Meta::Spec>, L<YAML>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
