@@ -1,16 +1,18 @@
 package Dist::Zilla::Plugin::ModuleBuild;
-BEGIN {
-  $Dist::Zilla::Plugin::ModuleBuild::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::ModuleBuild::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: build a Build.PL that uses Module::Build
 use List::MoreUtils qw(any uniq);
 use Moose;
 use Moose::Autobox;
-with 'Dist::Zilla::Role::BuildRunner';
-with 'Dist::Zilla::Role::PrereqSource';
-with 'Dist::Zilla::Role::InstallTool';
-with 'Dist::Zilla::Role::TextTemplate';
-with 'Dist::Zilla::Role::TestRunner';
+with (
+  'Dist::Zilla::Role::BuildPL',
+  'Dist::Zilla::Role::PrereqSource',
+  'Dist::Zilla::Role::TextTemplate',
+);
+
+use namespace::autoclean;
 
 use Dist::Zilla::File::InMemory;
 use List::MoreUtils qw(any uniq);
@@ -30,6 +32,12 @@ has 'mb_class' => (
   default => 'Module::Build',
 );
 
+has 'mb_lib' => (
+  isa => 'Str',
+  is  => 'rw',
+  default => 'inc'
+);
+
 my $template = q|
 use strict;
 use warnings;
@@ -39,6 +47,19 @@ use Module::Build {{ $plugin->mb_version }};
 
 my {{ $module_build_args }}
 
+unless ( eval { Module::Build->VERSION(0.4004) } ) {
+  my $tr = delete $module_build_args{test_requires};
+  my $br = $module_build_args{build_requires};
+  for my $mod ( keys %$tr ) {
+    if ( exists $br->{$mod} ) {
+      $br->{$mod} = $tr->{$mod} if $tr->{$mod} > $br->{$mod};
+    }
+    else {
+      $br->{$mod} = $tr->{$mod};
+    }
+  }
+}
+
 my $build = {{ $plugin->mb_class }}->new(%module_build_args);
 
 $build->create_build_script;
@@ -51,7 +72,7 @@ sub _use_custom_class {
     return "";
   }
   else {
-    return "use lib 'inc'; use $class;";
+    return sprintf "use lib qw{%s}; use $class;", join ' ', split ',', $self->mb_lib;
   }
 }
 
@@ -82,14 +103,11 @@ sub module_build_args {
   my %prereqs = (
     configure_requires => $prereqs->requirements_for(qw(configure requires)),
     build_requires     => $prereqs->requirements_for(qw(build     requires)),
+    test_requires      => $prereqs->requirements_for(qw(test      requires)),
     requires           => $prereqs->requirements_for(qw(runtime   requires)),
     recommends         => $prereqs->requirements_for(qw(runtime   recommends)),
   );
 
-  $prereqs{build_requires} = $prereqs{build_requires}->clone->add_requirements(
-    $prereqs->requirements_for(qw(test requires))
-  );
-
   (my $name = $self->zilla->name) =~ s/-/::/g;
 
   return {
@@ -123,6 +141,7 @@ sub setup_installer {
   );
   $module_build_dumper->Sortkeys( 1 );
   $module_build_dumper->Indent( 1 );
+  $module_build_dumper->Useqq( 1 );
 
   my $content = $self->fill_in_string(
     $template,
@@ -147,38 +166,22 @@ has __module_build_args => (
   isa  => 'HashRef',
 );
 
-sub build {
-  my $self = shift;
-
-  system($^X => 'Build.PL') and die "error with Build.PL\n";
-  system($^X, 'Build')      and die "error running $^X Build\n";
-
-  return;
-}
-
-sub test {
-  my ($self, $target) = @_;
-
-  $self->build;
-  system($^X, 'Build', 'test') and die "error running $^X Build test\n";
-
-  return;
-}
-
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::ModuleBuild - build a Build.PL that uses Module::Build
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -196,8 +199,25 @@ Defaults to 0.3601
 =head2 mb_class
 
 B<Optional:> Specify the class to use to create the build object.  Defaults
-to C<Module::Build> itself.  If another class is specified, C<use lib 'inc'>
-is also added to the Build.PL file.
+to C<Module::Build> itself.  If another class is specified, then the value
+of mb_lib will be used to generate a line like C<use lib 'inc'> to be added
+to the generated Build.PL file.
+
+=head2 mb_lib
+
+B<Optional:> Specify the list of directories to be passed to lib when using 
+mb_class. Defaults to C<inc>. 
+
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins:
+L<@Basic|Dist::Zilla::PluginBundle::Basic>,
+L<@Filter|Dist::Zilla::PluginBundle::Filter>,
+L<MakeMaker|Dist::Zilla::Plugin::MakeMaker>,
+L<Manifest|Dist::Zilla::Plugin::Manifest>.
+
+Dist::Zilla roles:
+L<BuildPL|Dist::Zilla::Role::BuildPL>.
 
 =head1 AUTHOR
 
@@ -205,10 +225,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
