@@ -1,10 +1,12 @@
 package Dist::Zilla::Plugin::ModuleShareDirs;
-BEGIN {
-  $Dist::Zilla::Plugin::ModuleShareDirs::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::ModuleShareDirs::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: install a directory's contents as module-based "ShareDir" content
 use Moose;
 
+use namespace::autoclean;
+
 use Moose::Autobox;
 
 
@@ -54,19 +56,21 @@ sub BUILDARGS {
 
 with 'Dist::Zilla::Role::ShareDir';
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::ModuleShareDirs - install a directory's contents as module-based "ShareDir" content
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 SYNOPSIS
 
@@ -82,10 +86,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
