@@ -1,27 +1,44 @@
 package Dist::Zilla::Plugin::PodCoverageTests;
-BEGIN {
-  $Dist::Zilla::Plugin::PodCoverageTests::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::PodCoverageTests::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: a release test for Pod coverage
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
+with 'Dist::Zilla::Role::PrereqSource';
 
+use namespace::autoclean;
+
+
+# Register the release test prereq as a "develop requires"
+# so it will be listed in "dzil listdeps --author"
+sub register_prereqs {
+  my ($self) = @_;
+
+  $self->zilla->register_prereqs(
+    {
+      type  => 'requires',
+      phase => 'develop',
+    },
+    'Test::Pod::Coverage'     => '1.08',
+    'Pod::Coverage::TrustPod' => 0,
+  );
+}
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
-
-
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::PodCoverageTests - a release test for Pod coverage
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -42,14 +59,13 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __DATA__
 ___[ xt/release/pod-coverage.t ]___
 #!perl
