@@ -1,27 +1,45 @@
 package Dist::Zilla::Plugin::PodSyntaxTests;
-BEGIN {
-  $Dist::Zilla::Plugin::PodSyntaxTests::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::PodSyntaxTests::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: a release test for Pod syntax
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
+with 'Dist::Zilla::Role::PrereqSource';
+
+use namespace::autoclean;
+
+
+
+# Register the release test prereq as a "develop requires"
+# so it will be listed in "dzil listdeps --author"
+sub register_prereqs {
+  my ($self) = @_;
+
+  $self->zilla->register_prereqs(
+    {
+      type  => 'requires',
+      phase => 'develop',
+    },
+    'Test::Pod' => '1.41',
+  );
+}
 
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
-
-
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::PodSyntaxTests - a release test for Pod syntax
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -30,20 +48,21 @@ following files:
 
   xt/release/pod-syntax.t   - a standard Test::Pod test
 
+L<Test::Pod> C<1.41> will be added as a C<develop requires> dependency.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __DATA__
 ___[ xt/release/pod-syntax.t ]___
 #!perl
