@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::PodVersion;
-BEGIN {
-  $Dist::Zilla::Plugin::PodVersion::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::PodVersion::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: add a VERSION head1 to each Perl document
 use Moose;
@@ -11,6 +11,8 @@ with(
   },
 );
 
+use namespace::autoclean;
+
 
 sub munge_files {
   my ($self) = @_;
@@ -52,30 +54,35 @@ sub munge_pod {
     );
 
     $self->log_debug([ 'adding VERSION Pod section to %s', $file->name ]);
-    $file->content(join "\n", @content);
+
+    my $content = join "\n", @content;
+    $content .= "\n" if length $content;
+    $file->content($content);
     return;
   }
 
   $self->log([
-    "couldn't find '=head1 VERSION' in %s, not adding '=head1 VERSION'",
+    "couldn't find '=head1 NAME' in %s, not adding '=head1 VERSION'",
     $file->name,
   ]);
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::PodVersion - add a VERSION head1 to each Perl document
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -84,16 +91,22 @@ distribution, indicating the version of the dist being built.  This section is
 added after C<=head1 NAME>.  If there is no such section, the version section
 will not be added.
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins:
+L<PkgVersion|Dist::Zilla::Plugin::PkgVersion>,
+L<AutoVersion|Dist::Zilla::Plugin::AutoVersion>,
+L<NextRelease|Dist::Zilla::Plugin::NextRelease>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
