@@ -1,12 +1,13 @@
 package Dist::Zilla::Plugin::Readme;
-BEGIN {
-  $Dist::Zilla::Plugin::Readme::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::Readme::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: build a README file
 use Moose;
 use Moose::Autobox;
-with 'Dist::Zilla::Role::FileGatherer';
-with 'Dist::Zilla::Role::TextTemplate';
+with qw/Dist::Zilla::Role::FileGatherer Dist::Zilla::Role::TextTemplate/;
+
+use namespace::autoclean;
 
 
 sub gather_files {
@@ -40,19 +41,21 @@ version {{ $dist->version }}:
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::Readme - build a README file
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -66,10 +69,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
