@@ -1,14 +1,21 @@
 package Dist::Zilla::Plugin::TemplateModule;
-BEGIN {
-  $Dist::Zilla::Plugin::TemplateModule::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::TemplateModule::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: a simple module-from-template plugin
 use Moose;
 with qw(Dist::Zilla::Role::ModuleMaker Dist::Zilla::Role::TextTemplate);
 
+use Path::Tiny;
+
+use namespace::autoclean;
+
 use autodie;
 
-use Data::Section 0.004 -setup; # fixed header_re
+use Sub::Exporter::ForMethods;
+use Data::Section 0.200002 # encoding and bytes
+  { installer => Sub::Exporter::ForMethods::method_installer },
+  '-setup';
 use Dist::Zilla::File::InMemory;
 
 
@@ -24,11 +31,7 @@ sub make_module {
   my $template;
 
   if ($self->has_template) {
-    open my $fh, '<', $self->template;
-
-    # Win32
-    binmode $fh, ':raw';
-    $template = do { local $/; <$fh> };
+    $template = path( $self->template )->slurp_utf8;
   } else {
     $template = ${ $self->section_data('Module.pm') };
   }
@@ -36,6 +39,7 @@ sub make_module {
   my $content = $self->fill_in_string(
     $template,
     {
+      dist => \($self->zilla),
       name => $arg->{name},
     },
   );
@@ -51,27 +55,28 @@ sub make_module {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
-
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::TemplateModule - a simple module-from-template plugin
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
 This is a L<ModuleMaker|Dist::Zilla::Role::ModuleMaker> used for creating new
 Perl modules files when minting a new dist with C<dzil new>.  It uses
 L<Text::Template> (via L<Dist::Zilla::Role::TextTemplate>) to render a template
-into a Perl module.  The only variable provided to the template is C<$name>,
-the module name.  The module is always created as a file under F<./lib>.
+into a Perl module.  The template is given two variables for use in rendering:
+C<$name>, the module name; and C<$dist>, the Dist::Zilla object.  The module is
+always created as a file under F<./lib>.
 
 By default, the template looks something like this:
 
@@ -86,7 +91,26 @@ By default, the template looks something like this:
 =head2 template
 
 The C<template> parameter may be given to the plugin to provide a different
-filename, absolute or relative to the build root.
+filename, absolute or relative to the build/profile directory.
+
+If this parameter is not specified, this module will use the boilerplate module
+template included in this module.
+
+=head1 MINTING CONFIGURATION
+
+This module is part of the standard configuration of the default L<Dist::Zilla>
+Minting Profile, and all profiles that don't set a custom ':DefaultModuleMaker'
+so you don't need to normally do anything to configure it.
+
+  dzil new Some::Module
+  # creates ./Some-Module/*
+  # creates ./Some-Module/lib/Some/Module.pm
+
+However, for those who wish to configure this ( or any subclasses ) this is
+presently required:
+
+  [TemplateModule / :DefaultModuleMaker]
+  ; template  = SomeFile.pm
 
 =head1 AUTHOR
 
@@ -94,14 +118,13 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __DATA__
 __[ Module.pm ]__
 use strict;
