@@ -1,13 +1,14 @@
 package Dist::Zilla::Plugin::TestRelease;
-BEGIN {
-  $Dist::Zilla::Plugin::TestRelease::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::TestRelease::VERSION = '5.000'; # TRIAL
 }
 use Moose;
 with 'Dist::Zilla::Role::BeforeRelease';
 # ABSTRACT: extract archive and run tests before releasing the dist
 
+use namespace::autoclean;
+
 
-use Archive::Tar;
 use File::pushd ();
 use Moose::Autobox;
 use Path::Class ();
@@ -23,6 +24,8 @@ sub before_release {
 
   $self->log("Extracting $tgz to $tmpdir");
 
+  require Archive::Tar;
+
   my @files = do {
     my $wd = File::pushd::pushd($tmpdir);
     Archive::Tar->extract_archive("$tgz");
@@ -32,29 +35,32 @@ sub before_release {
     unless @files;
 
   # Run tests on the extracted tarball:
-  my $target = $tmpdir->subdir( $self->zilla->built_in->dir_list(-1) );
+  my $target = $tmpdir->subdir( $self->zilla->dist_basename );
 
   local $ENV{RELEASE_TESTING} = 1;
+  local $ENV{AUTHOR_TESTING} = 1;
   $self->zilla->run_tests_in($target);
 
   $self->log("all's well; removing $tmpdir");
   $tmpdir->rmtree;
 }
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::TestRelease - extract archive and run tests before releasing the dist
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -64,6 +70,9 @@ tests.  If the tests fail, the release is aborted and the temporary directory
 is left in place.  If the tests pass, the temporary directory is cleaned up and
 the release process continues.
 
+This will set the RELEASE_TESTING and AUTHOR_TESTING env vars while running the
+test suite.
+
 =head1 CREDITS
 
 This plugin was originally contributed by Christopher J. Madsen.
@@ -74,10 +83,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
