@@ -1,16 +1,16 @@
 package Dist::Zilla::Plugin::UploadToCPAN;
-BEGIN {
-  $Dist::Zilla::Plugin::UploadToCPAN::VERSION = '4.101800';
+{
+  $Dist::Zilla::Plugin::UploadToCPAN::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: upload the dist to CPAN
 use Moose;
-with 'Dist::Zilla::Role::Releaser';
+with qw(Dist::Zilla::Role::BeforeRelease Dist::Zilla::Role::Releaser);
 
-use CPAN::Uploader 0.101550; # ua string
 use File::HomeDir;
 use File::Spec;
 use Moose::Util::TypeConstraints;
 use Scalar::Util qw(weaken);
+use Try::Tiny;
 
 use namespace::autoclean;
 
@@ -18,7 +18,9 @@ use namespace::autoclean;
 {
   package
     Dist::Zilla::Plugin::UploadToCPAN::_Uploader;
-  use base 'CPAN::Uploader';
+  # CPAN::Uploader will be loaded later if used
+  our @ISA = 'CPAN::Uploader';
+  # Report CPAN::Uploader's version, not ours:
   sub _ua_string { CPAN::Uploader->_ua_string }
 
   sub log {
@@ -52,6 +54,7 @@ sub mvp_aliases {
   return { user => 'username' };
 }
 
+
 has username => (
   is   => 'ro',
   isa  => 'Str',
@@ -59,10 +62,13 @@ has username => (
   required => 1,
   default  => sub {
     my ($self) = @_;
-    return $self->_credential('username') || $self->pause_cfg->{user};
+    return $self->_credential('username')
+        || $self->pause_cfg->{user}
+        || $self->zilla->chrome->prompt_str("PAUSE username: ");
   },
 );
 
+
 has password => (
   is   => 'ro',
   isa  => 'Str',
@@ -70,7 +76,9 @@ has password => (
   required => 1,
   default  => sub {
     my ($self) = @_;
-    return $self->_credential('password') || $self->pause_cfg->{password};
+    return $self->_credential('password')
+        || $self->pause_cfg->{password}
+        || $self->zilla->chrome->prompt_str('PAUSE password: ', { noecho => 1 });
   },
 );
 
@@ -83,26 +91,37 @@ has pause_cfg_file => (
   },
 );
 
+
 has pause_cfg => (
   is      => 'ro',
   isa     => 'HashRef[Str]',
   lazy    => 1,
   default => sub {
     my $self = shift;
-    open my $fh, '<', $self->pause_cfg_file
-      or return {};
-    my %ret;
-    # basically taken from the parsing code used by cpan-upload
-    # (maybe this should be part of the CPAN::Uploader api?)
-    while (<$fh>) {
-      next if /^\s*(?:#.*)?$/;
-      my ($k, $v) = /^\s*(\w+)\s+(.+)$/;
-      $ret{$k} = $v;
-    }
-    return \%ret;
+    require CPAN::Uploader;
+    my $cfg = try {
+      CPAN::Uploader->read_config_file( $self->pause_cfg_file );
+    } catch {
+      {};
+    };
+    return $cfg;
   },
 );
 
+
+has subdir => (
+    is        => 'ro',
+    isa       => 'Str',
+    predicate => 'has_subdir',
+);
+
+
+has upload_uri => (
+  is => 'ro',
+  isa => 'Str',
+  predicate => 'has_upload_uri',
+);
+
 has uploader => (
   is   => 'ro',
   isa  => 'CPAN::Uploader',
@@ -110,9 +129,17 @@ has uploader => (
   default => sub {
     my ($self) = @_;
 
+    # Load the module lazily
+    require CPAN::Uploader;
+    CPAN::Uploader->VERSION('0.103004');  # require HTTPS
+
     my $uploader = Dist::Zilla::Plugin::UploadToCPAN::_Uploader->new({
       user     => $self->username,
       password => $self->password,
+      ($self->has_subdir
+           ? (subdir => $self->subdir) : ()),
+      ($self->has_upload_uri
+           ? (upload_uri => $self->upload_uri) : ()),
     });
 
     $uploader->{'Dist::Zilla'}{plugin} = $self;
@@ -122,6 +149,21 @@ has uploader => (
   }
 );
 
+sub before_release {
+  my $self = shift;
+
+  my $problem;
+  try {
+    for my $attr (qw(username password)) {
+      $problem = $attr;
+      die unless length $self->$attr;
+    }
+    undef $problem;
+  };
+
+  $self->log_fatal(['You need to supply a %s', $problem]) if $problem;
+}
+
 sub release {
   my ($self, $archive) = @_;
 
@@ -129,19 +171,21 @@ sub release {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::UploadToCPAN - upload the dist to CPAN
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 SYNOPSIS
 
@@ -162,16 +206,48 @@ C<~/.pause>, in the same format that L<cpan-upload> requires:
   user YOUR-PAUSE-ID
   password YOUR-PAUSE-PASSWORD
 
+If neither configuration exists, it will prompt you to enter your
+username and password during the BeforeRelease phase.  Entering a
+blank username or password will abort the release.
+
+=head1 ATTRIBUTES
+
+=head2 username
+
+This option supplies the user's PAUSE username.  If not supplied, it will be
+looked for in the user's PAUSE configuration.
+
+=head2 password
+
+This option supplies the user's PAUSE password.  If not supplied, it will be
+looked for in the user's PAUSE configuration.
+
+=head2 pause_cfg
+
+This is a hashref of defaults loaded from F<~/.pause> -- this attribute is
+subject to removal in future versions, as the config-loading behavior in
+CPAN::Uploader is improved.
+
+=head2 subdir
+
+If given, this specifies a subdirectory under the user's home directory to
+which to upload.  Using this option is not recommended.
+
+=head2 upload_uri
+
+If given, this specifies an alternate URI for the PAUSE upload form.  By
+default, the default supplied by L<CPAN::Uploader> is used.  Using this option
+is not recommended in most cases.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
