@@ -1,11 +1,13 @@
 package Dist::Zilla::PluginBundle::Basic;
-BEGIN {
-  $Dist::Zilla::PluginBundle::Basic::VERSION = '4.101800';
+{
+  $Dist::Zilla::PluginBundle::Basic::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: the basic plugins to maintain and release CPAN dists
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
+use namespace::autoclean;
+
 sub configure {
   my ($self) = @_;
 
@@ -30,19 +32,21 @@ sub configure {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::PluginBundle::Basic - the basic plugins to maintain and release CPAN dists
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -112,20 +116,23 @@ L<Dist::Zilla::Plugin::UploadToCPAN>
 
 =back
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins: L<@Filter|Dist::Zilla::PluginBundle::Filter>.
+
+Dist::Zilla roles:
+L<PluginBundle|Dist::Zilla::Role::PluginBundle>,
+L<PluginBundle::Easy|Dist::Zilla::Role::PluginBundle::Easy>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
