@@ -1,10 +1,13 @@
 package Dist::Zilla::PluginBundle::FakeClassic;
-BEGIN {
-  $Dist::Zilla::PluginBundle::FakeClassic::VERSION = '4.101800';
+{
+  $Dist::Zilla::PluginBundle::FakeClassic::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: build something more or less like a "classic" CPAN dist
 use Moose;
 extends 'Dist::Zilla::PluginBundle::Classic';
+
+use namespace::autoclean;
+
 use Moose::Autobox;
 
 around bundle_config => sub {
@@ -27,19 +30,21 @@ around bundle_config => sub {
 };
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::PluginBundle::FakeClassic - build something more or less like a "classic" CPAN dist
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 AUTHOR
 
@@ -47,10 +52,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
