@@ -1,12 +1,15 @@
 package Dist::Zilla::PluginBundle::Filter;
-BEGIN {
-  $Dist::Zilla::PluginBundle::Filter::VERSION = '4.101800';
+{
+  $Dist::Zilla::PluginBundle::Filter::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: use another bundle, with some plugins removed
 use Moose;
 use Moose::Autobox;
 with 'Dist::Zilla::Role::PluginBundle';
 
+use namespace::autoclean;
+
+use Class::Load qw(try_load_class);
 use Dist::Zilla::Util;
 
 
@@ -31,13 +34,21 @@ sub bundle_config {
   Carp::croak("no bundle given for bundle filter")
     unless my $bundle = $config->{filter}->{bundle};
 
-  $bundle = Dist::Zilla::Util->expand_config_package_name($bundle);
+  my $pkg = Dist::Zilla::Util->expand_config_package_name($bundle);
 
-  Class::MOP::load_class($bundle);
+  my $load_opts = {};
+  if( my $v = $config->{filter}->{version} ){
+    $load_opts->{'-version'} = $v;
+  }
 
-  my @plugins = $bundle->bundle_config({
+  unless (try_load_class($pkg, $load_opts)) {
+    # XXX Naughty! -- rjbs, 2013-07-23
+    Config::MVP::Section->missing_package($pkg, $bundle);
+  }
+
+  my @plugins = $pkg->bundle_config({
     name    => $section->{name}, # not 100% sure about this -- rjbs, 2010-03-06
-    package => $bundle,
+    package => $pkg,
     payload => $config->{bundle} || {},
   });
 
@@ -54,48 +65,55 @@ sub bundle_config {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::PluginBundle::Filter - use another bundle, with some plugins removed
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 SYNOPSIS
 
 In your F<dist.ini>:
 
   [@Filter]
-  -bundle = @Classic
-  -remove = PodVersion
-  -remove = Manifest
-  option = for_classic
+  -bundle = @Basic
+  -remove = ShareDir
+  -remove = UploadToCPAN
+  option = for_basic
 
 =head1 DESCRIPTION
 
-This plugin bundle actually wraps and modified another plugin bundle.  It
+This plugin bundle actually wraps and modifies another plugin bundle.  It
 includes all the configuration for the bundle named in the C<-bundle> attribute,
 but removes all the entries whose package is given in the C<-remove> attributes.
 
 Options not prefixed with C<-> will be passed to the bundle to be filtered.
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins: L<@Basic|Dist::Zilla::PluginBundle::Basic>.
+
+Dist::Zilla roles: L<PluginBundle|Dist::Zilla::Role::PluginBundle>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
