@@ -1,27 +1,31 @@
 package Dist::Zilla::Role::BeforeArchive;
-BEGIN {
-  $Dist::Zilla::Role::BeforeArchive::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::BeforeArchive::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that runs before the archive file is built
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+use namespace::autoclean;
+
 
 requires 'before_archive';
 
-no Moose::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::BeforeArchive - something that runs before the archive file is built
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -34,10 +38,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
