@@ -1,27 +1,29 @@
 package Dist::Zilla::Role::ConfigDumper;
-BEGIN {
-  $Dist::Zilla::Role::ConfigDumper::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::ConfigDumper::VERSION = '5.000'; # TRIAL
 }
-# ABSTRACT: something that can dump its (public, simplified) configuraiton
+# ABSTRACT: something that can dump its (public, simplified) configuration
 use Moose::Role;
 
 use namespace::autoclean;
 
 sub dump_config { return {}; }
 
-no Moose::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Dist::Zilla::Role::ConfigDumper - something that can dump its (public, simplified) configuraiton
+Dist::Zilla::Role::ConfigDumper - something that can dump its (public, simplified) configuration
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 AUTHOR
 
@@ -29,10 +31,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
