@@ -1,11 +1,13 @@
 package Dist::Zilla::Role::ExecFiles;
-BEGIN {
-  $Dist::Zilla::Role::ExecFiles::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::ExecFiles::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that finds files to install as executables
 use Moose::Role;
 with 'Dist::Zilla::Role::FileFinder';
 
+use namespace::autoclean;
+
 requires 'dir';
 
 sub find_files {
@@ -18,15 +20,18 @@ sub find_files {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::ExecFiles - something that finds files to install as executables
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 AUTHOR
 
@@ -34,10 +39,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
