@@ -1,30 +1,33 @@
 package Dist::Zilla::Role::FileGatherer;
-BEGIN {
-  $Dist::Zilla::Role::FileGatherer::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::FileGatherer::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that gathers files into the distribution
 use Moose::Role;
-with 'Dist::Zilla::Role::Plugin';
-with 'Dist::Zilla::Role::FileInjector';
+with qw/Dist::Zilla::Role::Plugin Dist::Zilla::Role::FileInjector/;
+
+use namespace::autoclean;
 
 use Moose::Autobox;
 
 
 requires 'gather_files';
 
-no Moose::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::FileGatherer - something that gathers files into the distribution
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -42,10 +45,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
