@@ -1,10 +1,12 @@
 package Dist::Zilla::Role::FileInjector;
-BEGIN {
-  $Dist::Zilla::Role::FileInjector::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::FileInjector::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that can add files to the distribution
 use Moose::Role;
 
+use namespace::autoclean;
+
 use Moose::Autobox;
 
 
@@ -12,8 +14,7 @@ sub add_file {
   my ($self, $file) = @_;
   my ($pkg, undef, $line) = caller;
 
-  $file->meta->get_attribute('added_by')->set_value(
-    $file,
+  $file->_set_added_by(
     sprintf("%s (%s line %s)", $self->plugin_name, $pkg, $line),
   );
 
@@ -21,19 +22,21 @@ sub add_file {
   $self->zilla->files->push($file);
 }
 
-no Moose::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::FileInjector - something that can add files to the distribution
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -56,10 +59,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
