@@ -1,11 +1,13 @@
 package Dist::Zilla::Role::FileMunger;
-BEGIN {
-  $Dist::Zilla::Role::FileMunger::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::FileMunger::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that alters a file's destination or content
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+use namespace::autoclean;
+
 use Moose::Autobox;
 
 
@@ -18,19 +20,21 @@ sub munge_files {
   $self->munge_file($_) for $self->zilla->files->flatten;
 }
 
-no Moose::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::FileMunger - something that alters a file's destination or content
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -48,10 +52,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
