@@ -1,6 +1,6 @@
 package Dist::Zilla::Role::InstallTool;
-BEGIN {
-  $Dist::Zilla::Role::InstallTool::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::InstallTool::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that creates an install program for a dist
 use Moose::Role;
@@ -9,24 +9,28 @@ with qw(
   Dist::Zilla::Role::FileInjector
 );
 
+use namespace::autoclean;
+
 use Moose::Autobox;
 
 
 requires 'setup_installer';
 
-no Moose::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::InstallTool - something that creates an install program for a dist
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -34,8 +38,8 @@ Plugins implementing InstallTool have their C<setup_installer> method called to
 inject files after all other file injection and munging has taken place.
 They're expected to produce files needed to make the distribution
 installable, like F<Makefile.PL> or F<Build.PL> and add them with the
-C<add_file> method provided by L<Dist::Zilla::Role::FileInector>, which is also
-composed by this role.
+C<add_file> method provided by L<Dist::Zilla::Role::FileInjector>, which is
+also composed by this role.
 
 =head1 AUTHOR
 
@@ -43,10 +47,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
