@@ -1,27 +1,31 @@
 package Dist::Zilla::Role::MetaProvider;
-BEGIN {
-  $Dist::Zilla::Role::MetaProvider::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::MetaProvider::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that provides metadata (for META.yml/json)
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+use namespace::autoclean;
+
 
 requires 'metadata';
 
-no Moose::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::MetaProvider - something that provides metadata (for META.yml/json)
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -35,16 +39,24 @@ This method (which must be provided by classes implementing this role)
 returns a hashref of data to be (deeply) merged together with pre-existing
 metadata.
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins implementing this role:
+L<ConfigMeta|Dist::Zilla::Plugin::ConfigMeta>.
+L<MetaNoIndex|Dist::Zilla::Plugin::MetaNoIndex>.
+
+Dist::Zilla plugins on the CPAN:
+L<GithubMeta|Dist::Zilla::Plugin::GithubMeta>...
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
