@@ -1,29 +1,33 @@
 package Dist::Zilla::Role::MintingProfile;
-BEGIN {
-  $Dist::Zilla::Role::MintingProfile::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::MintingProfile::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that can find a minting profile dir
 use Moose::Role;
 
+use namespace::autoclean;
+
 use File::ShareDir;
 use Path::Class;
 
 
 requires 'profile_dir';
 
-no Moose::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::MintingProfile - something that can find a minting profile dir
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -48,10 +52,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
