@@ -1,11 +1,13 @@
 package Dist::Zilla::Role::MintingProfile::ShareDir;
-BEGIN {
-  $Dist::Zilla::Role::MintingProfile::ShareDir::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::MintingProfile::ShareDir::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that keeps its minting profile in a sharedir
 use Moose::Role;
 with 'Dist::Zilla::Role::MintingProfile';
 
+use namespace::autoclean;
+
 use File::ShareDir;
 use Path::Class;
 
@@ -21,19 +23,21 @@ sub profile_dir {
   confess "Can't find profile $profile_name via $self";
 }
 
-no Moose::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::MintingProfile::ShareDir - something that keeps its minting profile in a sharedir
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -46,10 +50,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
