@@ -1,6 +1,6 @@
 package Dist::Zilla::Role::ModuleMaker;
-BEGIN {
-  $Dist::Zilla::Role::ModuleMaker::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::ModuleMaker::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that injects module files into the dist
 use Moose::Role;
@@ -9,22 +9,26 @@ with qw(
   Dist::Zilla::Role::FileInjector
 );
 
+use namespace::autoclean;
+
 
 requires 'make_module';
 
-no Moose::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::ModuleMaker - something that injects module files into the dist
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -44,10 +48,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
