@@ -1,10 +1,12 @@
 package Dist::Zilla::Role::PluginBundle;
-BEGIN {
-  $Dist::Zilla::Role::PluginBundle::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::PluginBundle::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that bundles a bunch of plugins
 use Moose::Role;
 
+use namespace::autoclean;
+
 
 sub register_component {
   my ($class, $name, $arg, $self) = @_;
@@ -14,19 +16,21 @@ sub register_component {
 
 requires 'bundle_config';
 
-no Moose::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::PluginBundle - something that bundles a bunch of plugins
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -41,10 +45,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
