@@ -1,12 +1,14 @@
 package Dist::Zilla::Role::PluginBundle::Easy;
-BEGIN {
-  $Dist::Zilla::Role::PluginBundle::Easy::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::PluginBundle::Easy::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that bundles a bunch of plugins easily
 # This plugin was originally contributed by Christopher J. Madsen
 use Moose::Role;
 with 'Dist::Zilla::Role::PluginBundle';
 
+use namespace::autoclean;
+
 
 use Moose::Autobox;
 use MooseX::Types::Moose qw(Str ArrayRef HashRef);
@@ -95,7 +97,11 @@ sub add_bundle {
   my $package = _bundle_class($bundle);
   $payload  ||= {};
 
-  Class::MOP::load_class($package);
+  my $load_opts = {};
+  if( my $v = $payload->{':version'} ){
+    $load_opts->{'-version'} = $v;
+  }
+  Class::Load::load_class($package, $load_opts);
 
   $bundle = "\@$bundle" unless $bundle =~ /^@/;
 
@@ -132,15 +138,18 @@ sub config_slice {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::PluginBundle::Easy - something that bundles a bunch of plugins easily
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 SYNOPSIS
 
@@ -234,10 +243,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
