@@ -1,11 +1,13 @@
 package Dist::Zilla::Role::ShareDir;
-BEGIN {
-  $Dist::Zilla::Role::ShareDir::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::ShareDir::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that picks a directory to install as shared files
 use Moose::Role;
 with 'Dist::Zilla::Role::FileFinder';
 
+use namespace::autoclean;
+
 # Must return a hashref with any of the keys 'dist' and 'module'.  The 'dist'
 # must be a scalar with a directory to include and 'module' must be a hashref
 # mapping module names to directories to include.  If there are no directories
@@ -15,15 +17,18 @@ requires 'share_dir_map';
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::ShareDir - something that picks a directory to install as shared files
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 AUTHOR
 
@@ -31,10 +36,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
