@@ -1,10 +1,12 @@
 package Dist::Zilla::Role::Stash;
-BEGIN {
-  $Dist::Zilla::Role::Stash::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::Stash::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that stores options or data for later reference
 use Moose::Role;
 
+use namespace::autoclean;
+
 sub register_component {
   my ($class, $name, $arg, $section) = @_;
 
@@ -26,15 +28,18 @@ sub stash_from_config {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::Stash - something that stores options or data for later reference
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 AUTHOR
 
@@ -42,10 +47,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
