@@ -1,26 +1,31 @@
 package Dist::Zilla::Role::Stash::Authors;
-BEGIN {
-  $Dist::Zilla::Role::Stash::Authors::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::Stash::Authors::VERSION = '5.000'; # TRIAL
 }
 use Moose::Role;
 with 'Dist::Zilla::Role::Stash';
 # ABSTRACT: a stash that provides a list of author strings
 
+use namespace::autoclean;
+
 
 requires 'authors';
 
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::Stash::Authors - a stash that provides a list of author strings
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 OVERVIEW
 
@@ -33,10 +38,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
