@@ -1,27 +1,31 @@
 package Dist::Zilla::Role::VersionProvider;
-BEGIN {
-  $Dist::Zilla::Role::VersionProvider::VERSION = '4.101800';
+{
+  $Dist::Zilla::Role::VersionProvider::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: something that provides a version number for the dist
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+use namespace::autoclean;
+
 
 requires 'provide_version';
 
-no Moose::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::VersionProvider - something that provides a version number for the dist
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -32,16 +36,20 @@ If a VersionProvider offers a version but one has already been set, an
 exception will be raised.  If C<provides_version> returns undef, it will be
 ignored.
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins implementing this role:
+L<AutoVersion|Dist::Zilla::Plugin::AutoVersion>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
