@@ -1,10 +1,12 @@
 package Dist::Zilla::Stash::PAUSE;
-BEGIN {
-  $Dist::Zilla::Stash::PAUSE::VERSION = '4.101800';
+{
+  $Dist::Zilla::Stash::PAUSE::VERSION = '5.000'; # TRIAL
 }
 use Moose;
 # ABSTRACT: a stash of your PAUSE credentials
 
+use namespace::autoclean;
+
 
 sub mvp_aliases {
   return { user => 'username' };
@@ -23,18 +25,22 @@ has password => (
 );
 
 with 'Dist::Zilla::Role::Stash::Login';
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Stash::PAUSE - a stash of your PAUSE credentials
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 OVERVIEW
 
@@ -47,10 +53,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
