@@ -1,11 +1,13 @@
 package Dist::Zilla::Stash::Rights;
-BEGIN {
-  $Dist::Zilla::Stash::Rights::VERSION = '4.101800';
+{
+  $Dist::Zilla::Stash::Rights::VERSION = '5.000'; # TRIAL
 }
 use Moose;
 with 'Dist::Zilla::Role::Stash';
 # ABSTRACT: a stash of your default licensing terms
 
+use namespace::autoclean;
+
 has license_class => (
   is  => 'ro',
   isa => 'Str',
@@ -23,18 +25,22 @@ has copyright_year => (
   isa => 'Int',
 );
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Stash::Rights - a stash of your default licensing terms
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 AUTHOR
 
@@ -42,10 +48,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
