@@ -1,10 +1,12 @@
 package Dist::Zilla::Stash::User;
-BEGIN {
-  $Dist::Zilla::Stash::User::VERSION = '4.101800';
+{
+  $Dist::Zilla::Stash::User::VERSION = '5.000'; # TRIAL
 }
 use Moose;
 # ABSTRACT: a stash of user name and email
 
+use namespace::autoclean;
+
 has name => (
   is  => 'ro',
   isa => 'Str',
@@ -23,18 +25,22 @@ sub authors {
 }
 
 with 'Dist::Zilla::Role::Stash::Authors';
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Stash::User - a stash of user name and email
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 AUTHOR
 
@@ -42,10 +48,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
