@@ -1,11 +1,15 @@
 package Dist::Zilla::Tester;
-BEGIN {
-  $Dist::Zilla::Tester::VERSION = '4.101800';
+{
+  $Dist::Zilla::Tester::VERSION = '5.000'; # TRIAL
 }
 use Moose;
 extends 'Dist::Zilla::Dist::Builder';
 # ABSTRACT: a testing-enabling stand-in for Dist::Zilla
 
+# XXX: Adding this autoclean causes problem.  "Builder" and "Minter" do not
+# show in in tests.  I'm really not sure why. -- rjbs, 2011-08-19
+# use namespace::autoclean;
+
 use autodie;
 use Dist::Zilla::Chrome::Test;
 use File::pushd ();
@@ -33,10 +37,11 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 
 {
   package Dist::Zilla::Tester::_Role;
-BEGIN {
-  $Dist::Zilla::Tester::_Role::VERSION = '4.101800';
+{
+  $Dist::Zilla::Tester::_Role::VERSION = '5.000'; # TRIAL
 }
   use Moose::Role;
+  use Path::Tiny ();
 
   has tempdir => (
     is   => 'ro',
@@ -62,14 +67,17 @@ BEGIN {
   sub slurp_file {
     my ($self, $filename) = @_;
 
-    return scalar do {
-      local $/;
-      open my $fh, '<', $self->tempdir->file($filename);
+    Path::Tiny::path(
+      $self->tempdir->file($filename)
+    )->slurp_utf8;
+  }
 
-      # Win32.
-      binmode $fh, ':raw';
-      <$fh>;
-    };
+  sub slurp_file_raw {
+    my ($self, $filename) = @_;
+
+    Path::Tiny::path(
+      $self->tempdir->file($filename)
+    )->slurp_raw;
   }
 
   sub _metadata_generator_id { 'Dist::Zilla::Tester' }
@@ -79,8 +87,8 @@ BEGIN {
 
 {
   package Dist::Zilla::Tester::_Builder;
-BEGIN {
-  $Dist::Zilla::Tester::_Builder::VERSION = '4.101800';
+{
+  $Dist::Zilla::Tester::_Builder::VERSION = '5.000'; # TRIAL
 }
   use Moose;
   extends 'Dist::Zilla::Dist::Builder';
@@ -122,11 +130,7 @@ BEGIN {
       while (my ($name, $content) = each %$files) {
         my $fn = $tempdir->file($name);
         $fn->dir->mkpath;
-        open my $fh, '>', $fn;
-
-        # Win32 fix for crlf translation.
-        #   maybe :raw:utf8? -- Kentnl - 2010-06-10
-        binmode $fh, ':raw';
+        open my $fh, '>:raw:encoding(UTF-8)', $fn;
         print { $fh } $content;
         close $fh;
       }
@@ -160,7 +164,7 @@ BEGIN {
     return $self->$orig($target);
   };
 
-  around release => sub {
+  around ['test', 'release'] => sub {
     my ($orig, $self) = @_;
 
     # XXX: We *must eliminate* the need for this!  It's only here because right
@@ -175,8 +179,8 @@ BEGIN {
 
 {
   package Dist::Zilla::Tester::_Minter;
-BEGIN {
-  $Dist::Zilla::Tester::_Minter::VERSION = '4.101800';
+{
+  $Dist::Zilla::Tester::_Minter::VERSION = '5.000'; # TRIAL
 }
   use Moose;
   extends 'Dist::Zilla::Dist::Minter';
@@ -237,6 +241,8 @@ BEGIN {
 
     local @INC = map {; ref($_) ? $_ : File::Spec->rel2abs($_) } @INC;
 
+    local $ENV{DZIL_GLOBAL_CONFIG_ROOT} = $tester_arg->{global_config_root};
+
     my $global_stashes = $self->_setup_global_config(
       $tester_arg->{global_config_root},
       { chrome => $arg->{chrome} },
@@ -252,18 +258,23 @@ BEGIN {
   };
 }
 
+no Moose; # XXX: namespace::autoclean caused problems -- rjbs, 2011-08-19
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Tester - a testing-enabling stand-in for Dist::Zilla
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 AUTHOR
 
@@ -271,10 +282,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
