@@ -1,9 +1,11 @@
 package Dist::Zilla::Types;
-BEGIN {
-  $Dist::Zilla::Types::VERSION = '4.101800';
+{
+  $Dist::Zilla::Types::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: dzil-specific type library
 
+use namespace::autoclean;
+
 
 use MooseX::Types -declare => [qw(License OneZero YesNoStr)];
 use MooseX::Types::Moose qw(Str Int);
@@ -19,15 +21,18 @@ coerce OneZero, from YesNoStr, via { /\Ay/i ? 1 : 0 };
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Types - dzil-specific type library
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 OVERVIEW
 
@@ -43,10 +48,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
