@@ -1,19 +1,27 @@
 use strict;
 use warnings;
 package Dist::Zilla::Util;
-BEGIN {
-  $Dist::Zilla::Util::VERSION = '4.101800';
+{
+  $Dist::Zilla::Util::VERSION = '5.000'; # TRIAL
 }
 # ABSTRACT: random snippets of code that Dist::Zilla wants
 
+use Carp ();
 use String::RewritePrefix 0.002; # better string context behavior
 
 {
   package
     Dist::Zilla::Util::PEA;
-  use Pod::Eventual 0.091480; # better nonpod/blank events
-  use base 'Pod::Eventual';
-  sub _new  { bless {} => shift; }
+  @Dist::Zilla::Util::PEA::ISA = ('Pod::Eventual');
+  sub _new  {
+    # Load Pod::Eventual only when used (and not yet loaded)
+    unless (exists $INC{'Pod/Eventual.pm'}) {
+      require Pod::Eventual;
+      Pod::Eventual->VERSION(0.091480); # better nonpod/blank events
+    }
+
+    bless {} => shift;
+  }
   sub handle_nonpod {
     my ($self, $event) = @_;
     return if $self->{abstract};
@@ -38,7 +46,7 @@ use String::RewritePrefix 0.002; # better string context behavior
 
     if (
       $event->{type} eq 'text'
-      and $event->{content} =~ /^\S+\s+-+\s+(.+)$/
+      and $event->{content} =~ /^(?:\S+\s+)+?-+\s+(.+)\n$/s
     ) {
       $self->{abstract} = $1;
     }
@@ -47,9 +55,9 @@ use String::RewritePrefix 0.002; # better string context behavior
 
 
 sub abstract_from_file {
-  my ($self, $filename) = @_;
+  my ($self, $file) = @_;
   my $e = Dist::Zilla::Util::PEA->_new;
-  $e->read_file($filename);
+  $e->read_string($file->content);
   return $e->{abstract};
 }
 
@@ -70,18 +78,51 @@ sub expand_config_package_name {
   return $str;
 }
 
+sub _global_config_root {
+  require Path::Class;
+  return Path::Class::dir($ENV{DZIL_GLOBAL_CONFIG_ROOT}) if $ENV{DZIL_GLOBAL_CONFIG_ROOT};
+
+  require File::HomeDir;
+  my $homedir = File::HomeDir->my_home
+    or Carp::croak("couldn't determine home directory");
+
+  return Path::Class::dir($homedir)->subdir('.dzil');
+}
+
+sub _assert_loaded_class_version_ok {
+  my ($self, $pkg, $version) = @_;
+
+  require CPAN::Meta::Requirements;
+  my $req = CPAN::Meta::Requirements->from_string_hash({
+    $pkg => $version,
+  });
+
+  my $have_version = $pkg->VERSION;
+  unless ($req->accepts_module($pkg => $have_version)) {
+    die( sprintf
+      "%s version (%s) not match required version: %s\n",
+      $pkg,
+      $have_version,
+      $version,
+    );
+  }
+}
+
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Util - random snippets of code that Dist::Zilla wants
 
 =head1 VERSION
 
-version 4.101800
+version 5.000
 
 =head1 METHODS
 
@@ -105,10 +146,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
